/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : led_dimmer.c
* Author             : EMMA team Prague
* Date First Issued  : 12/21/2007
* Description        : This file contains all the functions prototypes for the
*                      lcd software driver.
********************************************************************************
* History:
* 12/21/2007: V0.0
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#include "led_dimmer.h"
#include "stm32f10x_systick.h"
#include "stm32f10x_nvic.h"
#include "stm32f10x_lib.h"
#include <stdlib.h>

#include "table_generator.h"

#define SPI1_DR_Address   (SPI1_BASE + 0x000C)  //computed by Ludek Holoubek 

unsigned int actual_streamSize = 1;
int actual_PWMdepth;

unsigned char *actual_table_start;
unsigned char *actual_table_key_start;
int actual_table_size;

unsigned char *new_table_start;
unsigned char *new_table_key_start;
int new_table_size;

unsigned char *released_table_start;
unsigned char *released_table_key_start;
int released_table_size;


int new_table_not_changed_yet_flag;

void fillDriver(int LEDcount, unsigned char pattern){
  unsigned short streamSizeToTest;
  int i;
  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;
  
  switch(pattern){
  case 0:
    for(i = 0; i < streamSizeToTest; i++){
      SPI_I2S_SendData(SPI1, 0x00);
      while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    }break;
  case 1:
    for(i = 0; i < streamSizeToTest; i++){
      SPI_I2S_SendData(SPI1, 0xFF);
      while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    }break;
  case 2:
    SPI_I2S_SendData(SPI1, 0x00);    //checking connection
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x24);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x2A);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x90);
    break;
  case 3:
    SPI_I2S_SendData(SPI1, 0x2A);    //no usb
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x04);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x2A);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x90);
    break;
  case 4:
    SPI_I2S_SendData(SPI1, 0x00);     //usb plugged
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x2A);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x04);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x2A);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    SPI_I2S_SendData(SPI1, 0x90);
    break;
  }
}  

int setup(int LEDcount, int PWMdepth, int requestedRefreshRate){ //set up refresh rate, configure interrupts and DMA
  NVIC_InitTypeDef NVIC_InitStructure;
  float TotalTime, SystickTime;
  long PreloadValue;
  TotalTime = (2.25 + 0.055 * LEDcount) * 0.000001;
  SystickTime = 1.0 / ((float)requestedRefreshRate * (float)PWMdepth);

  if(SystickTime < TotalTime)  //the values requested cannot be reached
    return ERROR;
  
  PreloadValue = 72000000 / (requestedRefreshRate * PWMdepth);

  SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK); //can be also set to SysTick_CLKSourceConfig(SysTick_CLKSource_HCLK_Div8);
  SysTick_SetReload(PreloadValue);

  /* Enable DMA channel6 IRQ Channel */
  NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel3_IRQChannel;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);
  SysTick_ITConfig(ENABLE);   //Enable the SysTick Interrupt

  actual_streamSize = LEDcount / 8;
  if(actual_streamSize*8 < LEDcount)
    actual_streamSize++;  
  
  released_table_start     = new_table_start     = actual_table_start     = NULL;
  released_table_key_start = new_table_key_start = actual_table_key_start = NULL;

  return SUCCESS;
}

  unsigned int DATAIN;

unsigned char error_detection_DMX(unsigned char *LEDmapIN, int LEDcount){
  unsigned int i, y, X, eFlag;
  GPIO_InitTypeDef GPIO_InitStructure;
  unsigned short streamSizeToTest;

  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;  
  
  stop_dimmer();
  LED_driver_OutDisable_All_Off();//LED_driver_OutDisable(1); LED_driver_OutDisable(2);

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();
  
  for(i = 0; i < 6; i++){
    SPI_I2S_SendData(SPI1, 0xFF);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
  }

  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();
  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();
  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);

  SPI_CLK_HIGH();
  SPI_CLK_LOW();

  GPIO_ResetBits(GPIOB, GPIO_Pin_2); //entering diagnostic mode

      SPI_CLK_LOW();SPI_CLK_LOW();SPI_CLK_LOW();SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();

  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);

      SPI_CLK_LOW();SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();

  for(i=0; i<3; i++)  
      X = 10+i+y;    

  SPI_CLK_HIGH();
  SPI_CLK_LOW();

    SPI_CLK_LOW();  SPI_CLK_LOW();
  
  LED_driver_OutDisable_All_Off();//LED_driver_OutDisable(1); LED_driver_OutDisable(2);  

  GPIO_SetBits(GPIOB, GPIO_Pin_2);  //leaving diagnostic mode  

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);

/*
  eFlag = 0;
  y = 1;
  DATAIN = SPI_ReceiveData(SPI1);  //clear the input buffer flag
  for(i = 0; i < (LEDcount/8); i++){
    SPI_SendData(SPI1, 0x00);                    //0x00 to prepare darkness
    while(SPI_GetFlagStatus(SPI1, SPI_FLAG_BSY));
    DATAIN = SPI_ReceiveData(SPI1);
    for( ; y<8; y++){
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)-1] = 1;
      else{
        LEDmapIN[(i*8+y)-1] = 0;
        eFlag = 1;        
      }
    }
    y = 0;
  }
*/

  eFlag = 0;
  DATAIN = SPI_I2S_ReceiveData(SPI1);  //clear the input buffer flag
  SPI_I2S_SendData(SPI1, 0x00);
  for(i = 0; i < (streamSizeToTest); i++){
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    DATAIN = SPI_I2S_ReceiveData(SPI1);
    SPI_I2S_SendData(SPI1, 0x00);
    for(y = 0; y<8; y++)
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)] = 1;
      else{
        LEDmapIN[(i*8+y)] = 0;
        eFlag = 1;        
      }
  }
  
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  
/*
  SPI_SendData(SPI1, 0x00);                    //0x00 to prepare darkness
  while(SPI_GetFlagStatus(SPI1, SPI_FLAG_BSY));
  DATAIN = SPI_ReceiveData(SPI1);
      if((DATAIN << y) & 0x80)
        LEDmapIN[((LEDcount/8)-1)*8 + 7] = 1;
      else{
        LEDmapIN[((LEDcount/8)-1)*8 + 7] = 0;
        eFlag = 1;
      }
  */

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();   //new
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();    //new

  return eFlag;

}

unsigned char error_detection_DM(unsigned char *LEDmapIN, int LEDcount){
  unsigned int i, y, X, eFlag;
  unsigned short streamSizeToTest;

  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;   stop_dimmer();
  LED_driver_OutDisable_All_Off();//LED_driver_OutDisable(1); LED_driver_OutDisable(2);

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();
  
  for(i = 0; i < 6; i++){
    SPI_I2S_SendData(SPI1, 0xFF);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
  }
  
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();
  GPIO_ResetBits(GPIOB, GPIO_Pin_2); //entering diagnostic mode

  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);

  for(i=0; i<3; i++)  
      X = 10+i+y;    
  
  SPI_I2S_SendData(SPI1, 0xFF);

  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);  

  GPIO_SetBits(GPIOB, GPIO_Pin_2);  //leaving diagnostic mode  

  eFlag = 0;
  y = 1;
  DATAIN = SPI_I2S_ReceiveData(SPI1);  //clear the input buffer flag
  for(i = 0; i < (LEDcount/8); i++){
    SPI_I2S_SendData(SPI1, 0x00);                    //0x00 to prepare darkness
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    DATAIN = SPI_I2S_ReceiveData(SPI1);
    for( ; y<8; y++){
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)-1] = 1;
      else{
        LEDmapIN[(i*8+y)-1] = 0;
        eFlag = 1;        
      }
    }
    y = 0;
  }
  
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  
  SPI_I2S_SendData(SPI1, 0x00);                    //0x00 to prepare darkness
  while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
  DATAIN = SPI_I2S_ReceiveData(SPI1);
      if((DATAIN << y) & 0x80)
        LEDmapIN[((LEDcount/8)-1)*8 + 7] = 1;
      else{
        LEDmapIN[((LEDcount/8)-1)*8 + 7] = 0;
        eFlag = 1;
      }

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();   //new
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();    //new

  return eFlag;

}

unsigned char error_detection_LE_OE(unsigned char *LEDmapIN, int LEDcount){
  unsigned int i, y, X, eFlag;
  unsigned short streamSizeToTest;
  GPIO_InitTypeDef GPIO_InitStructure;

  stop_dimmer();

  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();

  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;
  
  for(i = 0; i < streamSizeToTest; i++){
    SPI_I2S_SendData(SPI1, 0xFF);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
  }
  
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  
  //start point
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //LE=0
  SPI_CLK_LOW();
  //start point
  //sequence
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  GPIO_ResetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_low();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  //sequence - we have entered the test mode.

  for(i = 0; i < 48; i++){  //filling of 48 ones in to the driver
    SPI_CLK_HIGH();
    SPI_CLK_LOW();
  }
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH(); //latching of 48 ones to the driver
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();
  GPIO_ResetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_low();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();

/*  
  for(i=0; i<60; i++)  
    for(y=0; y<10; y++)
      X = 10+i+y;  
*/
  
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW();

  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);  //all the LED must be on for the test
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();


  for(i=0; i<10; i++)  
//    for(y=0; y<10; y++)
      X = 10+i+y;    


  SPI_CLK_HIGH();
  SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();
  
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);  //end of the measurement on the LEDs

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);  

  eFlag = 0;
  DATAIN = SPI_I2S_ReceiveData(SPI1);  //clear the input buffer flag
  for(i = 0; i < (streamSizeToTest); i++){
    SPI_I2S_SendData(SPI1, 0x00);
    while(SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_BSY));
    DATAIN = SPI_I2S_ReceiveData(SPI1);
    for(y = 0; y<8; y++)
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)] = 1;
      else{
        LEDmapIN[(i*8+y)] = 0;
        eFlag = 1;        
      }
  }

  GPIO_SetBits(GPIOA, GPIO_Pin_4);  //FAST_LE_HIGH(); //new
  GPIO_ResetBits(GPIOA, GPIO_Pin_4); //FAST_LE_LOW(); //new
 
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);      
      
  //end point
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  //end point
  
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  return eFlag;
}

void start_dimmer(void){      //enable main interrupt and start sending data to SPI
  SysTick_CounterCmd(SysTick_Counter_Enable);
}
  
void stop_dimmer(void){       //disable main interrupt and stop sending data to SPI
  SysTick_CounterCmd(SysTick_Counter_Disable);
}

void LED_driver_OutEnable_All_On(void){   //enable OE
  GPIO_ResetBits(GPIOB, GPIO_Pin_13); //Blue  OE1B
  GPIO_ResetBits(GPIOB, GPIO_Pin_11); //Green OE1G
  GPIO_ResetBits(GPIOB, GPIO_Pin_10); //Red   OE1R
  GPIO_ResetBits(GPIOB, GPIO_Pin_12); //Blue  OE2B
  GPIO_ResetBits(GPIOB, GPIO_Pin_1);  //Green OE2G
  GPIO_ResetBits(GPIOB, GPIO_Pin_0);  //Red   OE2R
}

void LED_driver_OutDisable_All_Off(void){   //disable signal OE
  GPIO_SetBits(GPIOB, GPIO_Pin_13); //Blue  OE1B
  GPIO_SetBits(GPIOB, GPIO_Pin_11); //Green OE1G
  GPIO_SetBits(GPIOB, GPIO_Pin_10); //Red   OE1R
  GPIO_SetBits(GPIOB, GPIO_Pin_12); //Blue  OE2B
  GPIO_SetBits(GPIOB, GPIO_Pin_1);  //Green OE2G
  GPIO_SetBits(GPIOB, GPIO_Pin_0);  //Red   OE2R
}

void LED_driver_OutEnable(unsigned char which, unsigned char RGBchannel){   //enable OE
  if(which == 1)
  {
    if(RGBchannel & 0x01) GPIO_ResetBits(GPIOB, GPIO_Pin_13); //Blue  OE1B
    if(RGBchannel & 0x02) GPIO_ResetBits(GPIOB, GPIO_Pin_11); //Green OE1G
    if(RGBchannel & 0x04) GPIO_ResetBits(GPIOB, GPIO_Pin_10); //Red   OE1R
  }
  if(which == 2)
  {
    if(RGBchannel & 0x01) GPIO_ResetBits(GPIOB, GPIO_Pin_12); //Blue  OE2B
    if(RGBchannel & 0x02) GPIO_ResetBits(GPIOB, GPIO_Pin_1);  //Green OE2G
    if(RGBchannel & 0x04) GPIO_ResetBits(GPIOB, GPIO_Pin_0);  //Red   OE2R
  }
}

void LED_driver_OutDisable(unsigned char which, unsigned char RGBchannel){   //disable signal OE
  if(which == 1)
  {
    if(RGBchannel & 0x01) GPIO_SetBits(GPIOB, GPIO_Pin_13); //Blue  OE1B
    if(RGBchannel & 0x02) GPIO_SetBits(GPIOB, GPIO_Pin_11); //Green OE1G
    if(RGBchannel & 0x04) GPIO_SetBits(GPIOB, GPIO_Pin_10); //Red   OE1R
  }
  if(which == 2)
  {
    if(RGBchannel & 0x01) GPIO_SetBits(GPIOB, GPIO_Pin_12); //Blue  OE2B
    if(RGBchannel & 0x02) GPIO_SetBits(GPIOB, GPIO_Pin_1);  //Green OE2G
    if(RGBchannel & 0x04) GPIO_SetBits(GPIOB, GPIO_Pin_0);  //Red   OE2R
  }
}

void SPI_CLK_LOW(void){
  GPIO_ResetBits(GPIOA, GPIO_Pin_5);
}

void SPI_CLK_HIGH(void){
  GPIO_SetBits(GPIOA, GPIO_Pin_5);
}

void use_new_table_immediately(unsigned char *table, unsigned char *tableKey, int table_size){ //exchange table(SPI data) not preventing glitch,
  released_table_start     = actual_table_start;
  released_table_key_start = actual_table_key_start;
  released_table_size      = actual_table_size;

  actual_table_start     = table;
  actual_table_key_start = tableKey;
  actual_table_size      = table_size;
  
  new_table_not_changed_yet_flag = 0;
}

void use_new_table_carefully(unsigned char *table, unsigned char *tableKey, int table_size){
  new_table_not_changed_yet_flag = 1; //exchange table(SPI data) preventing glitch, in right time

  released_table_start     = actual_table_start;
  released_table_key_start = actual_table_key_start;
  released_table_size      = actual_table_size;

  new_table_start     = table;
  new_table_key_start = tableKey;
  new_table_size      = table_size;
}
  
int new_table_not_changed_yet(void){ //true till right time for table not reached
  return new_table_not_changed_yet_flag;
}
  
int generateReducedLookUpTable(unsigned char *LEDmapIN, int LEDcount, int PWMdepth, unsigned char **tableIN, unsigned char **tableKeyIN, int *table_sizeIN){
//  *tableIN = generateFullLookUpTable(LEDmapIN, LEDcount, PWMdepth);
//  *table_sizeIN = 256;
  performGenerateReducedLookUpTable(LEDmapIN, LEDcount, PWMdepth, tableIN, tableKeyIN, table_sizeIN);

  if((*tableIN)&&(*tableKeyIN))
    return SUCCESS;
  else
    return ERROR;
}

void removeLookUpTableInUse(void){
  if(actual_table_start)
    free(actual_table_start);
  if(actual_table_start)
    free(actual_table_start);
}

void removeLookUpTableReleased(void){
  if(released_table_start)
    free(released_table_start);
  if(released_table_key_start)
    free(released_table_key_start);
}

void RCC_Configuration(void)
{
  /* System Clocks Configuration -----------------------------------------------*/
  RCC_DeInit();

#ifdef _IAR_BOARD
  RCC_HSEConfig(RCC_HSE_ON);  /* Enable HSE */
  while(RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET);   /* Wait till HSE is ready */
#endif
  
  /* Flash 2 wait state */
  *(vu32 *)0x40022000 = 0x02;

  RCC_HCLKConfig(RCC_SYSCLK_Div1);  /* HCLK = SYSCLK */
  RCC_PCLK2Config(RCC_HCLK_Div1);  /* PCLK2 = HCLK */
  RCC_PCLK1Config(RCC_HCLK_Div2);  /* PCLK1 = HCLK/2 */
#ifdef _IAR_BOARD
  RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);  /* PLLCLK = 8MHz * 9 = 72 MHz */
#else
  RCC_PLLConfig(RCC_PLLSource_HSI_Div2, RCC_PLLMul_12);  /* PLLCLK = 4MHz * 12 = 48 MHz */
  //  RCC_MCOConfig(RCC_MCO_SYSCLK); //for debug purposes to see internal clock
#endif

  RCC_PLLCmd(ENABLE);  /* Enable PLL */ 

  while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  /* Wait till PLL is ready */

  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);  /* Select PLL as system clock source */

  while(RCC_GetSYSCLKSource() != 0x08);  /* Wait till PLL is used as system clock source */
 
  /* Enable GPIOA, GPIOB, GPIOC, GPIOD, GPIOE and AFIO clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB | RCC_APB2Periph_GPIOC
                         | RCC_APB2Periph_GPIOD | RCC_APB2Periph_GPIOE | RCC_APB2Periph_ADC1
                         | RCC_APB2Periph_AFIO, ENABLE);

  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);  /* Enable DMA clock */
 
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_SPI2, ENABLE);  /* SPI2 Periph clock enable */
}

void NVIC_Configuration(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;
  
#ifdef VECT_TAB_FLASH
  /* Set the Vector Table base address at 0x08000000 */
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);
#elif VECT_TAB_RAM
  /* Set the Vector Table base address at 0x20000000 */
  NVIC_SetVectorTable(NVIC_VectTab_RAM, 0x0);
#endif
 
  /* Enable DMA channel6 IRQ Channel */
  NVIC_InitStructure.NVIC_IRQChannel = DMA1_Channel3_IRQChannel;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);

  /* Enable SPI1 IRQ Channel */
/*
  NVIC_InitStructure.NVIC_IRQChannel = SPI1_IRQChannel;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);
  */
}

u32 getSemiRnd(void){
  return SysTick_GetCounter();
}

void SPI_DMA_Init(void)
{
  DMA_InitTypeDef DMA_InitStructure;
  SPI_InitTypeDef  SPI_InitStructure;
  GPIO_InitTypeDef GPIO_InitStructure;

  /* Enable DMA clock */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);
  
  /* DMA Channel1 Configuration ----------------------------------------------*/
  DMA_DeInit(DMA1_Channel3);
  DMA_InitStructure.DMA_PeripheralBaseAddr = SPI1_DR_Address;
  DMA_InitStructure.DMA_MemoryBaseAddr = (u32) actual_table_start; //&LookUp;
  DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralDST;
  DMA_InitStructure.DMA_BufferSize = 0x04;
  DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;
  DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;
  DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_Byte; //DMA_PeripheralDataSize_Word;
  DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_Byte; //DMA_MemoryDataSize_Word;
  DMA_InitStructure.DMA_Mode = DMA_Mode_Normal; //DMA_Mode_Circular;//DMA_Mode_Normal;
  DMA_InitStructure.DMA_Priority = DMA_Priority_VeryHigh;
  DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;
  DMA_Init(DMA1_Channel3, &DMA_InitStructure);

  /* Enable DMA Channel1 */
  DMA_Cmd(DMA1_Channel3, ENABLE);
  DMA_ITConfig(DMA1_Channel3, DMA_IT_TC, ENABLE);
  
  /* Enable SPI1 and GPIOA clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1 | RCC_APB2Periph_GPIOA, ENABLE);
  
  /* Configure SPI1 pins: (NSS), SCK, MISO and MOSI */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;                       //!!!!!! QUESTION FOR PUSH PULL
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;                         //!!! FOR MISO
  GPIO_Init(GPIOA, &GPIO_InitStructure);

  /* Configure PA.4 as Output push-pull, used as LatchEnable select */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);

  /* Configure PB.0 and .1 as Output push-pull, used as OE1 and OE2 and PB.2 as DM - diagnostic mode*/
  GPIO_SetBits(GPIOB, GPIO_Pin_0);
  GPIO_SetBits(GPIOB, GPIO_Pin_1);
  GPIO_SetBits(GPIOB, GPIO_Pin_2);
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_10 | GPIO_Pin_11 | GPIO_Pin_12 | GPIO_Pin_13;
//  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOB, &GPIO_InitStructure);
  GPIO_SetBits(GPIOB, GPIO_Pin_0);
  GPIO_SetBits(GPIOB, GPIO_Pin_1);
  GPIO_SetBits(GPIOB, GPIO_Pin_2);

  /* MCO master clock output - mainly for debugging purpose*/  
  /*
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  */
  /* SPI1 configuration */ 
  SPI_InitStructure.SPI_Direction = SPI_Direction_2Lines_FullDuplex;
  SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
  SPI_InitStructure.SPI_DataSize = SPI_DataSize_8b;
  SPI_InitStructure.SPI_CPOL = SPI_CPOL_High;
  SPI_InitStructure.SPI_CPHA = SPI_CPHA_2Edge;
  SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
  SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_2;
  SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;
  SPI_InitStructure.SPI_CRCPolynomial = 7;
  SPI_Init(SPI1, &SPI_InitStructure);
  
  SPI_Cmd(SPI1, ENABLE);     /* Enable SPI1  */
  SPI_I2S_DMACmd(SPI1, SPI_I2S_DMAReq_Tx, ENABLE);  //interface between SPI and DMA
}

/*******************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/*
nice effect

SPI_SendData(SPI1, 0xFF0F);
  SPI_SendData(SPI1, 0xFF00);
  SPI_SendData(SPI1, 0xFFF0);
  SPI_SendData(SPI1, 0xFF0F);
  SPI_SendData(SPI1, 0xFF00);
  SPI_SendData(SPI1, 0xFFF0);
*/
