/**
* @file  serial.h
* @brief Header file for the HAL RS232 serial interface APIs.
*/
/****************** (C) COPYRIGHT 2006 STMicroelectronics **********************
* Author              MCD Application Team
* Date First Issued   11/13/2006
* History:
* 12/11/2006 : V1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SERIAL_H
#define __SERIAL_H
#include "stm32f10x_type.h"

/* Includes ------------------------------------------------------------------*/
/* Exported types ------------------------------------------------------------*/
#define APP_SERIAL 0
#define APP_SERIAL_PORT 1
#define ST_CORE_UART         USART1
#define ST_CORE_UART_CHANNEL USART1_IRQChannel
#define ST_CORE_UART_GPIO    GPIOA
#define ST_CORE_UART_GPIO_RX_PIN GPIO_Pin_10  /* pin 10 */
#define ST_CORE_UART_GPIO_TX_PIN GPIO_Pin_9  /* pin 9 */

/* Assign numerical values for the set of Baud Rates */
enum {
  BAUD_300 = 0,
  BAUD_600 = 1,
  BAUD_900 = 2,
  BAUD_1200 = 3,
  BAUD_2400 = 4,
  BAUD_4800 = 5,
  BAUD_9600 = 6,
  BAUD_14400 = 7,
  BAUD_19200 = 8,
  BAUD_28800 = 9,
  BAUD_38400 = 10,
  BAUD_50000 = 11,
  BAUD_57600 = 12,
  BAUD_76800 = 13,
  BAUD_100000 = 14,
  BAUD_115200 = 15,
  BAUD_CUSTOM = 16
};

/* Assign numerical values for the types of parity */
enum {
  PARITY_NONE = 0,
  PARITY_ODD = 1,
  PARITY_EVEN = 2
};

/* Exported constants  -------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Exported variables  -------------------------------------------------------*/

extern u8 usb_plugged;

/** Description: Keep the read byte over the serial port */
extern u8 bRByte;
/** Description: Flag to signal data over the uart */
extern u8 bRByteReady;
/* Exported functions --------------------------------------------------------*/

/** Description: Serial port initialization */
void emberSerialInit(void);

/** Description: Print on the serial port */
void emberSerialPrintf(u8 serial_port, char *str, ...);

/** Description: Serial wait */
void emberSerialWaitSend(u8 port);

/** Description: Read a byte over the serial port */
u8 emberSerialReadByte(u8 port, u8 *dataByte);


/** Description:Currently emberSerialGuaranteedPrintf is mapped to 
	emberSerialPrintf (tbr)*/
#ifdef ST_ST7
#define emberSerialGuaranteedPrintf emberSerialPrintf 
#else
#ifdef __IAR_SYSTEMS_ICC__    
    #define emberSerialGuaranteedPrintf emberSerialPrintf  
#else
    #define emberSerialGuaranteedPrintf(port,x,...) emberSerialPrintf(port,x) 
#endif //__IAR_SYSTEMS_ICC__
#endif /* ST_ST7 */
#endif /* __SERIAL_H */

/******************* (C) COPYRIGHT 2006 STMicroelectronics *****END OF FILE****/
