/**
  ******************************************************************************
  * @file ADC_ContinuousConversion\main.c
  * @brief This file contains the main function for the ADC Continuous Conversion example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  **************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  * 
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"
#include "main.h"

/**
  * @addtogroup ADC_ContinuousConversion
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Public functions ----------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u16 Conversion_Value = 0;

/**
  * @brief ADC_Example1 Example  main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - GPIO_Init()
  * - ADC_DeInit()
  * - ADC_Init()
  * - ADC_StartConversion()
  * - ADC_GetFlagStatus()
  * - ADC_GetConversionValue()
  * - ADC_ClearFlag()
  * - ADC_ITCmd()
  * - enableInterrupts()
  */
void main(void)
{
    /*  Init GPIO for ADC */
    GPIO_Init(GPIOE, GPIO_PIN_6, GPIO_MODE_IN_FL_NO_IT);

    /* Init GPIO for LED  */
    GPIO_Init(LEDS_PORT, (LED1_PIN |LED2_PIN |LED3_PIN |LED4_PIN), GPIO_MODE_OUT_PP_LOW_FAST);


    ADC_DeInit();

    enableInterrupts();

    /* Init ADC peripheral */
    ADC_Init(ADC_CONVERSIONMODE_CONTINUOUS, ADC_CHANNEL_9, ADC_PRESSEL_FCPU_D2, ADC_EXTTRIG_TIM1, DISABLE, ADC_ALIGN_RIGHT, ADC_SCHMITTTRIG_CHANNEL9, DISABLE);

    /* Enable EOC interrupt */
    ADC_ITConfig(ADC_IT_EOCITEN, ENABLE);

    /*Start Conversion */
    ADC_StartConversion();

    while (1)
    {
        /* The LEDs state are changed in the interrupt routine */
    }

}

/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
    while (1)
    {
    }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
