/**
  ******************************************************************************
  * @file ADC_TriggerConversion\main.c
  * @brief This file contains the main function for the ADC Trigger Conversion example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  * 
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"
#include "main.h"

/**
  * @addtogroup ADC_TriggerConversion
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Public functions ----------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/

/**
  * @brief Example main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - GPIO_Init()
  * - ADC_DeInit()
  * - ADC_Init()
  * - ADC_StartConversion()
  * - ADC_GetFlagStatus()
  * - ADC_GetConversionValue()
  * - ADC_ClearFlag()
  * - ADC_ITConfig()
	* - TIM1_SelectMasterSlaveMode()
	* - TIM1_SelectOutputTrigger()
	* - TIM1_Cmd()
  * - enableInterrupts()
  */
void main(void)
{
    /*  Init GPIO for ADC */
    GPIO_Init(GPIOE, GPIO_PIN_6, GPIO_MODE_IN_FL_NO_IT);

    /* Init GPIO for LED  */
    GPIO_Init(LEDS_PORT, (LED1_PIN |LED2_PIN |LED3_PIN |LED4_PIN), GPIO_MODE_OUT_PP_LOW_FAST);


    ADC_DeInit();

    enableInterrupts();


    /* Configure the conversion mode and the channel to convert  */
    ADC_ConversionConfig(ADC_CONVERSIONMODE_CONTINUOUS, ADC_CHANNEL_9, ADC_ALIGN_RIGHT);

    /* Configure the schmitt trigger channel and state */
    ADC_SchmittTriggerConfig(ADC_SCHMITTTRIG_CHANNEL9, DISABLE);

    /* Enable the ADC peripheral */
    ADC_Cmd(ENABLE);

    /* Enable EOC interrupt */
    ADC_ITConfig(ADC_IT_EOCITEN, ENABLE);

    /* Configure the TIM1 Master/Slave mode */
    TIM1_SelectMasterSlaveMode(ENABLE);

    /*Configure the ADC external trigger */
    ADC_ExternalTriggerConfig(ADC_EXTTRIG_TIM, ENABLE);

    /* Trigger the conversion */
    TIM1_SelectOutputTrigger(TIM1_TRGOSOURCE_ENABLE);
    TIM1_Cmd(ENABLE);


    while (1)
    {
        /* The LEDs are changed in the interrupt routine */
    }


}

/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
    while (1)
    {

    }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
