/**
  ******************************************************************************
  * @file CLK_ManualCLKSwitch\main.c
  * @brief This file contains the main function for the CLK Manual Clock Switching example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"
#include "main.h"

/**
  * @addtogroup CLK_ManualCLKSwitch
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
u8 ReadJoystick(void);
void Delay (u16 nCount);

/* Private functions ---------------------------------------------------------*/
u8 ReadJoystick(void)
{
    /* "right" key is pressed */
    if ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_4) == (u8)0x00)
    {
        while ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_4) == Bit_RESET);
        return RIGHT;
    }
    /* "up" key is pressed */
    else if ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_6) == (u8)0x00)
    {
        while ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_6) == Bit_RESET);
        return UP;
    }
    /* "down" key is pressed */
    else if ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_7) == (u8)0x00)
    {
        while ((GPIO_ReadInputData(GPIOB) & GPIO_PIN_7) == Bit_RESET);
        return DOWN;
    }

}


void Delay(u16 nCount)
{
    /* Decrement nCount value */
    while (nCount != 0)
    {
        nCount--;
    }
}

/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
/* Public functions ----------------------------------------------------------*/
/**
  * @brief Example  main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
	* - GPIO_WriteReverse()
  * - CLK_DeInit()
  * - CLK_Init()
  * - CLK_ClockSwitchConfig()
  * - CLK_CCOConfig()
	* - CLK_ClockSwitchCmd()
  * - enableInterrupts()
  */
void main(void)
{

    ErrorStatus status = FALSE;
    u8 MyKey = 0;
    u8 i = 0, j = 0;


    /* Init GPIO for LED  */
    GPIO_Init(LEDS_PORT, (LED1_PIN |LED2_PIN |LED3_PIN |LED4_PIN), GPIO_MODE_OUT_PP_LOW_FAST);


    CLK_DeInit();

    /* Output Fmaster on CLK_CCO pin */
    CLK_CCOConfig(CLK_OUTPUT_MASTER);

    while (1)
    {
        /* Read Key */
        MyKey = ReadJoystick();

        if ((MyKey == UP))
        {
            status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_MANUAL, CLK_SOURCE_HSE, DISABLE, DISABLE);
            CLK_ClockSwitchCmd(ENABLE);
            /* Toggle LEDs quickly then stop */
            for (j = 20; j > 0; j--)
            {
                GPIO_WriteReverse(LEDS_PORT, (LED1_PIN | LED2_PIN | LED3_PIN));
                for (i = 2; i > 0; i--)
                {
                    Delay((u16)60000);
                }
            }
        }
        if (MyKey == DOWN)
        {
            status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_MANUAL, CLK_SOURCE_LSI, DISABLE, DISABLE);
            CLK_ClockSwitchCmd(ENABLE);
            /* Toggle LEDs quickly then stop */
            for (j = 20; j > 0; j--)
            {
                GPIO_WriteReverse(LEDS_PORT, (LED1_PIN | LED2_PIN | LED3_PIN));
                for (i = 2; i > 0; i--)
                {
                    Delay((u16)60000);
                }
            }
        }
        if (MyKey == RIGHT)
        {
            status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_MANUAL, CLK_SOURCE_HSI, DISABLE, DISABLE);
            CLK_ClockSwitchCmd(ENABLE);
            /* Toggle LEDs quickly then stop */
            for (j = 20; j > 0; j--)
            {
                GPIO_WriteReverse(LEDS_PORT, (LED1_PIN | LED2_PIN | LED3_PIN));
                for (i = 2; i > 0; i--)
                {
                    Delay((u16)60000);
                }
            }
        }
    }



}

/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
    while (1)
    {
    }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
