/**
  ******************************************************************************
  * @file SPI_IAP\main.c
  * @brief This file contains the main function for SPI IAP example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"
#include "mono_lcd.h"

/**
  * @addtogroup SPI_IAP
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/

/* Evalboard I/Os configuration */

#define LEDS_PORT (GPIOH)
#define LED1_PIN  (GPIO_PIN_3)
#define LED2_PIN  (GPIO_PIN_2)
#define LED3_PIN  (GPIO_PIN_1)
#define LED4_PIN  (GPIO_PIN_0)

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
volatile BoolT WREN;
volatile BoolT WRT;
volatile BoolT READ;
u32 Start_add_RW;
u8 SPI_Buffer_Rx[133];
u8 Index;
u8 NbData;



/* Private function prototypes -----------------------------------------------*/
void Delay (u16 nCount);

/* Private functions ---------------------------------------------------------*/

void Delay(u16 nCount)
{
  /* Decrement nCount value */
  while (nCount != 0)
  {
    nCount--;
  }
}

/* Global variables ----------------------------------------------------------*/
BoolT ButtonPressed = FALSE;

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Validation firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - SPI_Init()
	* - SPI_DeInit()
	* - SPI_Cmd()
	* - SPI_SendData()
	* - SPI_ReceiveData()
	* - GPIO_WriteHigh()
  * - GPIO_WriteLow()
	* - EXTI_SetExtIntSensitivity() 
	* - CLK_HSIPrescalerConfig()
	* - FLASH_Unlock()
  */
void main(void)
{
  /*High speed internal clock prescaler: 1*/
  CLK_HSIPrescalerConfig(CLK_PRESCALER_HSIDIV1);
	
  /* Initialization of the Interrupt sensitivity */
  EXTI_SetExtIntSensitivity(EXTI_PORT_GPIOC, EXTI_SENSITIVITY_FALL_ONLY);

 /* Initialize SPI in Master mode (for LCD only) */
  SPI_DeInit();
	SPI_Init(SPI_FIRSTBIT_MSB, SPI_BAUDRATEPRESCALER_128, SPI_MODE_MASTER, SPI_CLOCKPOLARITY_LOW, SPI_CLOCKPHASE_1EDGE, SPI_DATADIRECTION_2LINES_FULLDUPLEX, SPI_NSS_SOFT, 0x07);

  SPI_Cmd(ENABLE);
	/*** LCD ***/
  LCD_Init();
	LCD_Clear();
  LCD_PrintString(LCD_LINE1, ENABLE, DISABLE, " *** STM8S *** ");
  LCD_PrintString(LCD_LINE2, ENABLE, DISABLE, "  IAP-SPI Demo ");

  /* Initialize SPI in Slave mode (for IAP-SPI programming) */
	SPI_Init(SPI_FIRSTBIT_MSB, SPI_BAUDRATEPRESCALER_128, SPI_MODE_SLAVE, SPI_CLOCKPOLARITY_LOW, SPI_CLOCKPHASE_1EDGE, SPI_DATADIRECTION_2LINES_FULLDUPLEX, SPI_NSS_HARD, 0x07);
  SPI_Cmd(ENABLE);
	
	/*** Unlock FLASH ***/
	FLASH_Unlock(FLASH_MEMTYPE_PROG);
	FLASH_Unlock(FLASH_MEMTYPE_DATA);

	Start_add_RW = 0x009000;
	NbData = 0;
	
	/* POLLING */
	while (1)
  {
		while ((GPIOE->IDR & 0x20) != 0x00)
		{
			SPI_SendData(0x00);
		}
		
		if ((SPI->SR & SPI_FLAG_RXNE)==SPI_FLAG_RXNE)
		{
			SPI_Buffer_Rx[NbData] = SPI_ReceiveData();
			
			if ((NbData == 1) && (WREN == TRUE))
			{
				if (SPI_Buffer_Rx[NbData] == 0x02)
				{
					NbData++;
					while ((GPIOE->IDR & 0x20) == 0x00)
					{
						if ((SPI->SR & SPI_FLAG_RXNE)==SPI_FLAG_RXNE)
						{
							SPI_Buffer_Rx[NbData++] = SPI_ReceiveData();
						}
					}
					Start_add_RW = (u32)((u32)SPI_Buffer_Rx[4] + ((u32)SPI_Buffer_Rx[3] << 8) + ((u32)SPI_Buffer_Rx[2] << 8));
					if (NbData > 4)
					{
						for (Index = 5; Index < NbData; Index++)
						{
							FLASH_ProgramByte(Start_add_RW++, SPI_Buffer_Rx[Index]);
						}
						/*Clear SPI_Buffer_RX & variables*/
						for (Index = 0; Index < 134; Index++)
						{
							SPI_Buffer_Rx[Index] = 0x00;
						}
						WREN = FALSE;
						NbData = 0;
					}
				}
			}

			if ((NbData == 0) && (SPI_Buffer_Rx[0] == 0x06))
			{
				WREN = TRUE;
				SPI_SendData(0x00);
				NbData++;
			}
			
			if ((NbData == 0) && (SPI_Buffer_Rx[0] == 0x03))
			{
				NbData++;
				
				while ((GPIOE->IDR & 0x20) == 0x00)
				{
					if (NbData < 4)
					{
						while ((SPI->SR & SPI_FLAG_RXNE) != SPI_FLAG_RXNE);
						SPI_Buffer_Rx[NbData++] = SPI_ReceiveData();
						if (NbData == 4)
						{
							Start_add_RW = (u32)((u32)SPI_Buffer_Rx[3] + ((u32)SPI_Buffer_Rx[2] << 8) + ((u32)SPI_Buffer_Rx[1] << 8));
						}
					}
					else
					{
						SPI_SendData(FLASH_ReadByte(Start_add_RW++));
						while ((SPI->SR & SPI_FLAG_TXE != SPI_FLAG_TXE));

						while ((SPI->SR & SPI_FLAG_RXNE) != SPI_FLAG_RXNE);
						SPI_Buffer_Rx[NbData++] = SPI_ReceiveData();
					}
				}
				
				/*Clear SPI_Buffer_RX & Variables */
				for (Index = 0; Index < 134; Index++)
				{
					SPI_Buffer_Rx[Index] = 0x00;
				}
				NbData = 0;
				
			}
			
		}

  }

}

/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Infinite loop */
  while (1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
