/**
  ******************************************************************************
  * @file TIM3_Input_Capture\main.c
  * @brief This file contains the main function for TIM3 Input Capture example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"

/**
  * @addtogroup TIM3_Input_Capture
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u32 TIM3ClockFreq = 2000000;
u32 LSIClockFreq = 0;
u16 ICValue1, ICValue2;

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Example firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - TIM3_ICInit
  * - TIM3_ITConfig
  * - TIM3_Cmd
  * - TIM3_ClearFlag
  * - GPIO_Init
  * - TIM3_GetCapture1
  */
void main(void)
{
  /* -----------------------------------------------------------------------
  This example shows how to configure the TIM3 peripheral to capture with another way the LSI.

  TIM3CLK is fixed to 2 MHz, the TIM3 Prescaler is equal to 1 so the TIM3 counter
  clock used is 2 MHz. (By default, fTimer1= fMaster/8 )
  
	The TIM3 Channel 1 is configured as Input capture.
	The LSI signal is redirected to the CCO output Pin.
	The TIM3 Channel 1 is connected to the CCO Pin. 
  
	Connect the configurable Clock Output pin CCO pin to the TIM3 CH1 TIM3_CC1.
	- TIM3_CH1  pin (PD.2)  
	- CCO pin 	(PE.0)
	
  The value of LSI Frequency is stored in the LSIClockFreq variable.
  ----------------------------------------------------------------------- */


	/* Capture only every 8 events!!! */
  /* Enable capture of TI1 */
	TIM3_ICInit(TIM3_CHANNEL_1, TIM3_ICPOLARITY_FALLING, TIM3_ICSELECTION_DIRECTTI,   TIM3_ICPSC_DIV8, 0x00);
  
	/* Enable CC1 interrupt */
	TIM3_ITConfig(TIM3_IT_CC1, ENABLE); 
	
	/* Enable timer2 */
  TIM3_Cmd(ENABLE);
	
	TIM3->SR1 = 0x00;
  TIM3->SR2 = 0x00;
	
	/* Clear CC1 Flag*/
  TIM3_ClearFlag(TIM3_FLAG_CC1);
  
	/* Connect LSI to COO pin*/
  GPIO_Init(GPIOE, GPIO_PIN_0, GPIO_MODE_OUT_PP_LOW_FAST);
  CLK->CCOR |= 0x03;
	
	
	/* wait a capture on cc1 */
  while((TIM3->SR1 & TIM3_FLAG_CC1) != TIM3_FLAG_CC1);
  /* Get CCR1 value*/
	ICValue1 = TIM3_GetCapture1();
	TIM3_ClearFlag(TIM3_FLAG_CC1);
  
	/* wait a capture on cc1 */
  while((TIM3->SR1 & TIM3_FLAG_CC1) != TIM3_FLAG_CC1);
  /* Get CCR1 value*/
	ICValue2 = TIM3_GetCapture1();
	TIM3_ClearFlag(TIM3_FLAG_CC1);

  /* Compute LSI clock frequency */
  LSIClockFreq = (8 * TIM3ClockFreq) / (ICValue2 - ICValue1);
  
	/* Insert a break point here */
	nop();
  while (1)
  {
  }    
}


/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Put enter your own code to manage an assert error */
    while(1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
