/**
  ******************************************************************************
  * @file TIM3_OC_InactiveMode\main.c
  * @brief This file contains the main function for TIM3 OC Inactive Mode Example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"

/**
  * @addtogroup TIM3_OC_InactiveMode
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u16 CCR1_Val = 976;
u16 CCR2_Val = 488;

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Example firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - TIM3_DeInit
  * - TIM3_TimeBaseInit
  * - TIM3_OC1Init
  * - TIM3_OC2Init
  * - TIM3_Cmd
  * - TIM3_PrescalerConfig
  * - TIM3_ARRPreloadConfig
  * - TIM3_ITConfig
  * - GPIO_Init
  * - GPIO_WriteHigh
  */
void main(void)
{
 /* ---------------------------------------------------------------
  TIM3 Configuration: generate 2 signals with 2 different delays:
  TIM3CLK = 2 MHz, Prescaler = 2048, TIM3 counter clock = 976 Hz
  TIM3_CH1 delay = CCR1_Val/TIM3 counter clock  = 1000 ms
  TIM3_CH2 delay = CCR2_Val/TIM3 counter clock  =500 ms 
--------------------------------------------------------------- */

  /* Time base configuration */
  TIM3_TimeBaseInit(TIM3_PRESCALER_2048, 65535);

  /* Prescaler configuration */
  TIM3_PrescalerConfig(TIM3_PRESCALER_2048, TIM3_PSCRELOADMODE_IMMEDIATE);

  /* Output Compare Active Mode configuration: Channel1 */
	TIM3_OC1Init(TIM3_OCMODE_INACTIVE,  TIM3_OUTPUTSTATE_ENABLE, CCR1_Val,  TIM3_OCPOLARITY_HIGH);
  TIM3_OC1PreloadConfig(DISABLE);

  /* Output Compare Active Mode configuration: Channel2 */
  TIM3_OC2Init(TIM3_OCMODE_INACTIVE,  TIM3_OUTPUTSTATE_ENABLE, CCR2_Val,  TIM3_OCPOLARITY_HIGH);
  TIM3_OC2PreloadConfig(DISABLE);

  TIM3_ARRPreloadConfig(ENABLE);
  
  /* TIM IT enable */
  TIM3_ITConfig(TIM3_IT_CC1, ENABLE);
  TIM3_ITConfig(TIM3_IT_CC2, ENABLE);

  /* Set PG.5 and PG.6 pin to high state */
  GPIO_Init(GPIOG, (GPIO_PIN_5 |GPIO_PIN_6 ), GPIO_MODE_OUT_PP_LOW_FAST);
	GPIO_WriteHigh(GPIOG, GPIO_PIN_5 |GPIO_PIN_6 );
	
  
  /* TIM3 enable counter */
  TIM3_Cmd(ENABLE);
	
	enableInterrupts();

  while (1)
  {
  }    
}


/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Put enter your own code to manage an assert error */
    while(1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
