/**
  ******************************************************************************
  * @file TIM3_PWM_DutyCycleConfiguration\main.c
  * @brief This file contains the main function for TIM3 PWM Duty Cycle Configuration example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"

/**
  * @addtogroup TIM3_PWM_DutyCycleConfiguration
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u16 CCR1_Val = 500;
u16 CCR2_Val = 250;


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Example firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - TIM3_DeInit
  * - TIM3_TimeBaseInit
  * - TIM3_OC1Init
  * - TIM3_OC2Init
  * - TIM3_Cmd
  */
void main(void)
{
/* -----------------------------------------------------------------------
  TIM3 Configuration: generate 2 PWM signals with 2 different duty cycles:
  TIM3CLK = 2 MHz, Prescaler = 1, TIM3 counter clock = 2 MHz/1 = 2 MHz
  TIM3 ARR Register = 999 => TIM3 Frequency = TIM3 counter clock/(ARR + 1) 
  TIM3 Frequency = 2 KHz.
  TIM3 Channel1 duty cycle = (TIM3_CCR1/ TIM3_ARR)* 100 = 50% 
  TIM3 Channel2 duty cycle = (TIM3_CCR2/ TIM3_ARR)* 100 = 25% 
----------------------------------------------------------------------- */

   /* Time base configuration */ 
  TIM3_TimeBaseInit(TIM3_PRESCALER_1, 999);

  /* PWM1 Mode configuration: Channel1 */
  TIM3_OC1Init(TIM3_OCMODE_PWM1, TIM3_OUTPUTSTATE_ENABLE, CCR1_Val,  TIM3_OCPOLARITY_HIGH);
  TIM3_OC1PreloadConfig(ENABLE);

  /* PWM1 Mode configuration: Channel2 */ 
  TIM3_OC2Init(TIM3_OCMODE_PWM1, TIM3_OUTPUTSTATE_ENABLE, CCR2_Val,  TIM3_OCPOLARITY_HIGH);
  TIM3_OC2PreloadConfig(ENABLE);
  
  TIM3_ARRPreloadConfig(ENABLE);

  /* TIM3 enable counter */
  TIM3_Cmd(ENABLE);

  while (1)
  {
  }  
}


/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Put enter your own code to manage an assert error */
    while(1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
