/**
  ******************************************************************************
  * @file TIM3_PWM_FrequencyConfiguration\main.c
  * @brief This file contains the main function for TIM3 PWM Frequency Configuration example.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"

/**
  * @addtogroup TIM3_PWM_FrequencyConfiguration
  * @{
  */

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
vu16 CCR1_Val = 32768;
vu16 CCR2_Val = 16384;

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Example firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - TIM3_DeInit
  * - TIM3_TimeBaseInit
  * - TIM3_OC1Init
  * - TIM3_OC2Init
  * - TIM3_Cmd
  */
void main(void)
{
 /* ---------------------------------------------------------------
  TIM3 Configuration: Output Compare Toggle Mode:
  TIM3CLK = 2 MHz, Prescaler = 2, TIM3 counter clock = 1 MHz
  CC1 update rate = TIM3 counter clock / CCR1_Val =  30.51 Hz
  CC2 update rate = TIM3 counter clock / CCR2_Val =  61.03 Hz 
--------------------------------------------------------------- */

  /* Time base configuration */
  TIM3_TimeBaseInit(TIM3_PRESCALER_2, 65535);

  /* Output Compare Toggle Mode configuration: Channel1 */
  TIM3_OC1Init(TIM3_OCMODE_TOGGLE,TIM3_OUTPUTSTATE_ENABLE, CCR1_Val, TIM3_OCPOLARITY_LOW);
	
  TIM3_OC1PreloadConfig(DISABLE);

  /* Output Compare Toggle Mode configuration: Channel2 */
  TIM3_OC2Init(TIM3_OCMODE_TOGGLE,TIM3_OUTPUTSTATE_ENABLE, CCR2_Val, TIM3_OCPOLARITY_LOW);
  TIM3_OC2PreloadConfig(DISABLE);



  /* TIM3 IT enable */
  TIM3_ITConfig(TIM3_IT_CC1,ENABLE);
  TIM3_ITConfig(TIM3_IT_CC2,ENABLE);

	/* TIM3 enable counter */
  TIM3_Cmd(ENABLE);

	enableInterrupts();
  while (1)
  {
  }   
}


/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Put enter your own code to manage an assert error */
    while(1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
