/**
  ******************************************************************************
  * @file UART1_LIN\main.c
  * @brief This file contains the main function for UART1 example3.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_lib.h"
#include "stm8s_it.h"

/**
  * @addtogroup UART1_LIN
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
typedef enum
{
  Idle,
  SendBreak,
  VerifBreak,
  SendSynch,
  VerifSynch,
  SendPID,
  SendData,
  VerifData
} LIN_MASTER_state;

typedef enum
{
  Init,
  WaitHeader,
  WaitData
} LIN_SLAVE_state;

/* Private define ------------------------------------------------------------*/

/* Evalboard I/Os configuration */

#define LEDs_PORT (GPIOH)
#define LED1_PIN  (GPIO_PIN_3)
#define LED2_PIN  (GPIO_PIN_2)
#define LED3_PIN  (GPIO_PIN_1)
#define LED4_PIN  (GPIO_PIN_0)

#define UART2_Init_PORT         (GPIOF)
#define UART1_Init_PORT       (GPIOG)
#define UART2_Multiplexer_PIN   (GPIO_PIN_5 | GPIO_PIN_6)
#define UART2_EN_PIN            (GPIO_PIN_7)
#define UART1_Multiplexer_PIN (GPIO_PIN_6)
#define UART1_EN_PIN          (GPIO_PIN_3)

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
u8 Data[] = {0xAA, 0x67, 0xFF, 0xA9, 0x34, 0x90, 0x7F, 0x8A}; /* Data to send */
u8 i = 0; /* Data Number that MASTER send */
u8 j = 0; /* Data Number that SLAVE receive */
u8 PID = 0x1E; /* PID of this frame */

LIN_MASTER_state LIN_MASTER = Idle;
LIN_SLAVE_state LIN_SLAVE = Init;

/* Private function prototypes -----------------------------------------------*/
void Delay (u16 nCount);

/* Private functions ---------------------------------------------------------*/

void Delay(u16 nCount)
{
  /* Decrement nCount value */
  while (nCount != 0)
  {
    nCount--;
  }
}

/* Public functions ----------------------------------------------------------*/

/**
  * @brief Example firmware main entry point.
  * @par Parameters:
  * None
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Library functions called:
  * - GPIO_Init()
  * - GPIO_ReadInputData()
  * - GPIO_WriteHigh()
  * - GPIO_WriteLow()
  * - UART2_LINCmd()
  * - UART2_Init()
  * - UART2_ITConfig()
  * - UART2_SendBreak()
  * - UART2_SendData8()
  * - UART1_LINCmd()
  * - UART1_Init()
  * - UART1_LINConfig()
  * - UART1_ReceiverWakeUpCmd()
  * - UART1_ITConfig()
  * - UART1_ReceiveData8()
	* - CLK_HSIPrescalerConfig()
  * - enableInterrupts()
 */

void main(void)
{
  /*High speed internal clock prescaler: 1*/
  CLK_HSIPrescalerConfig(CLK_PRESCALER_HSIDIV1);/* Set CPU frequency to 16MHz */
	
  /* Initialize UART2 as a MASTER node */
  UART2_LINCmd(ENABLE);
  UART2_Init((u32)4800, UART2_WORDLENGTH_8D, UART2_STOPBITS_1, UART2_PARITY_NO, UART2_SYNCMODE_CLOCK_DISABLE, UART2_MODE_TXRX_ENABLE);


  GPIO_Init(UART2_Init_PORT, UART2_Multiplexer_PIN | UART2_EN_PIN, GPIO_MODE_OUT_PP_LOW_FAST);

  /* Choose LIN1 as the ouput port of UART2 */
  GPIO_WriteLow(UART2_Init_PORT, UART2_Multiplexer_PIN);

  /* Enable LIN1 */
  GPIO_WriteHigh(UART2_Init_PORT, UART2_EN_PIN);

  /* Initialize UART1 as a SLAVE node */
  UART1_LINCmd(ENABLE);

	UART1_Init((u32)4800, UART1_WORDLENGTH_8D, UART1_STOPBITS_1, UART1_PARITY_NO, UART1_MODE_TXRX_ENABLE);


  UART1_LINConfig(UART1_LIN_MODE_SLAVE, UART1_LIN_AUTOSYNC_ENABLE, UART1_LIN_DIVUP_LBRR1);
  UART1_ReceiverWakeUpCmd(ENABLE);

  GPIO_Init(UART1_Init_PORT, UART1_Multiplexer_PIN | UART1_EN_PIN, GPIO_MODE_OUT_PP_LOW_FAST);
  /* Choose LIN2 as the ouput port of UART1 */
  GPIO_WriteLow(UART1_Init_PORT, UART1_Multiplexer_PIN);

  /* Enable LIN2 */
  GPIO_WriteHigh(UART1_Init_PORT, UART1_EN_PIN);

  /* Initialize LEDs */
  GPIO_Init(LEDs_PORT, LED1_PIN | LED2_PIN | LED3_PIN | LED4_PIN, GPIO_MODE_OUT_PP_LOW_FAST);

  /* Just to check LEDs */
  GPIO_WriteHigh(LEDs_PORT, (LED1_PIN | LED2_PIN | LED3_PIN | LED4_PIN));
  Delay(0xFFFF);
  GPIO_WriteLow(LEDs_PORT, (LED1_PIN | LED2_PIN | LED3_PIN | LED4_PIN));

  enableInterrupts();

  while (1)
  {
    switch (LIN_MASTER)
    {
      case Idle:
        Delay(0xFFFF);
        Delay(0xFFFF);
        LIN_MASTER = SendBreak;
        /* Configurate Interruption for UART2
        Enable IT of Break detection, disable IT of Data Detection */
        UART2_ITConfig(UART2_IT_LBD, ENABLE);
        UART2_ITConfig(UART2_IT_RXNE_ORE, DISABLE);
        break;

      case SendBreak:
        UART2_SendBreak();
        LIN_MASTER = VerifBreak;
        break;

      case VerifBreak:
        if (BreakReceived)
        {
          BreakReceived = 0;
          LIN_MASTER = SendSynch;
          /* Configurate Interruption for UART2
          Enable IT of Data detection, disable IT of Break Detection */
          UART2_ITConfig(UART2_IT_RXNE_ORE, ENABLE);
          UART2_ITConfig(UART2_IT_LBD, DISABLE);
        }
        break;

      case SendSynch:
        UART2_SendData8(0x55);
        LIN_MASTER = VerifSynch;

        break;

      case VerifSynch:
        if (UART2_DataReceived)
        {
          UART2_DataReceived = 0;
          LIN_MASTER = SendPID;
        }
        break;

      case SendPID:
        UART2_SendData8(PID);
        LIN_MASTER = VerifData;
        break;

      case SendData:
        UART2_SendData8(Data[i]);
        i++;
        LIN_MASTER = VerifData;
        break;

      case VerifData:
        if (UART2_DataReceived)
        {
          UART2_DataReceived = 0;
          if (i < 8)
          {
            LIN_MASTER = SendData;
          }
          else
          {
            i = 0;
            LIN_MASTER = Idle;
          }
        }
    };
    switch (LIN_SLAVE)
    {
      case Init:
        /* Configurate Interruption for UART1
        Enable IT of Header detection, disable IT of Data detection */
        UART1_ITConfig(UART1_IT_PE, ENABLE);
				UART1_ITConfig(UART1_IT_LHD, ENABLE);
        UART1_ITConfig(UART1_IT_RXNE_ORE, DISABLE);
        LIN_SLAVE = WaitHeader;
        break;

      case WaitHeader:
        if (HeaderReceived)
        {
          HeaderReceived = 0;
          UART1_DataReceived = 0;
          DataTemp = UART1_ReceiveData8();
          if (DataTemp == PID)
          {
            /* GPIO_WriteHigh(LEDs_PORT, LED1_PIN); */
          }
          LIN_SLAVE = WaitData;
          /* Configurate Interruption for UART1
          Enable IT of Data detection, disable IT of Header detection */
          UART1_ITConfig(UART1_IT_RXNE_ORE, ENABLE);
          UART1_ITConfig(UART1_IT_PE, DISABLE);
					UART1_ITConfig(UART1_IT_LHD, DISABLE);
        }
        break;

      case WaitData:
        /* GPIO_WriteLow(LEDs_PORT, LED1_PIN | LED2_PIN); */
        if (UART1_DataReceived)
        {
          UART1_DataReceived = 0;
          DataTemp = UART1_ReceiveData8();
          if (DataTemp == Data[j])
          {
            GPIO_WriteReverse(LEDs_PORT, LED2_PIN);
          }
          j++;
          if (j == 8)
          {
            LIN_SLAVE = Init;
            j = 0;
          }
        }
    };

    if (LIN_Error)
    {
      LIN_Error = Correct;
      i = 0;
      j = 0;
      LIN_MASTER = Idle;
      LIN_SLAVE = WaitHeader;
      BreakReceived = 0;
      HeaderReceived = 0;
      UART2_DataReceived = 0;
      UART1_DataReceived = 0;
    }
  }
}

/**
  * @brief Reports the name of the source file and the source line number where
  * the assert error has occurred.
  * User can add his own implementation to report the file name and line number.
  * ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line)
  * @retval void None
  * @par Required preconditions:
  * None
  * @par Called functions:
  * None
  */
#ifdef FULL_ASSERT
void assert_failed(u8 *file, u16 line)
#else
void assert_failed(void)
#endif
{
  /* Infinite loop */
  while (1)
  {
  }
}

/**
  * @}
  */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
