/**
  ******************************************************************************
  * @file stm8s_adc.h
  * @brief This file contains all the prototypes/macros for the ADC peripheral.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM8S_ADC_H
#define __STM8S_ADC_H

/* Includes ------------------------------------------------------------------*/
#include "stm8s_map.h"

/* Exported types ------------------------------------------------------------*/

/** @addtogroup ADC_Exported_Types
  * @{
  */

/**
  * @brief ADC clock prescaler selection
  */

typedef enum {
  ADC_PRESSEL_FCPU_D2  = (u8)0x00, /**< Prescaler selection fadc = fcpu/2 */
  ADC_PRESSEL_FCPU_D3  = (u8)0x10, /**< Prescaler selection fadc = fcpu/3 */
  ADC_PRESSEL_FCPU_D4  = (u8)0x20, /**< Prescaler selection fadc = fcpu/4 */
  ADC_PRESSEL_FCPU_D6  = (u8)0x30, /**< Prescaler selection fadc = fcpu/6 */
  ADC_PRESSEL_FCPU_D8  = (u8)0x40, /**< Prescaler selection fadc = fcpu/8 */
  ADC_PRESSEL_FCPU_D10 = (u8)0x50, /**< Prescaler selection fadc = fcpu/10 */
  ADC_PRESSEL_FCPU_D12 = (u8)0x60, /**< Prescaler selection fadc = fcpu/12 */
  ADC_PRESSEL_FCPU_D18 = (u8)0x70  /**< Prescaler selection fadc = fcpu/18 */
} ADC_PresSel_TypeDef;

/**
  * @brief  ADC External conversion trigger event selection
  */
typedef enum {
  ADC_EXTTRIG_TIM   = (u8)0x00, /**< Conversion from Internal TIM TRGO event */
  ADC_EXTTRIG_GPIO  = (u8)0x10  /**< Conversion from External interrupt on GPIO Port */
} ADC_ExtTrig_TypeDef;

/**
  * @brief ADC data alignment
  */
typedef enum {
  ADC_ALIGN_LEFT  = (u8)0x00, /**< Data alignment left */
  ADC_ALIGN_RIGHT = (u8)0x08  /**< Data alignment right */
} ADC_Align_TypeDef;

/**
  * @brief ADC Interrupt source
  */
typedef enum {
  ADC_IT_AWDGITEN  = (u16)0x10, /**< Analog WDG interrupt enable */
  ADC_IT_EOCITEN   = (u16)0x20, /**< EOC iterrupt enable */
  ADC_IT_AWDG    = (u8)0x140, /**< Analog WDG status */
  ADC_IT_AWDGS0  = (u8)0x110, /**< Analog channel 0 status */
  ADC_IT_AWDGS1  = (u8)0x111, /**< Analog channel 1 status */
  ADC_IT_AWDGS2  = (u8)0x112, /**< Analog channel 2 status */
  ADC_IT_AWDGS3  = (u8)0x113, /**< Analog channel 3 status */
  ADC_IT_AWDGS4  = (u8)0x114, /**< Analog channel 4 status */
  ADC_IT_AWDGS5  = (u8)0x115, /**< Analog channel 5 status */
  ADC_IT_AWDGS6  = (u8)0x116, /**< Analog channel 6 status */
  ADC_IT_AWDGS7  = (u8)0x117, /**< Analog channel 7 status */
  ADC_IT_AWDGS8  = (u8)0x118, /**< Analog channel 8 status */
  ADC_IT_AWDGS9  = (u8)0x119, /**< Analog channel 9 status */
  ADC_IT_EOC     = (u8)0x80  /**< EOC pending bit */

} ADC_IT_TypeDef;

/**
  * @brief ADC Flags
  */
typedef enum {
  ADC_FLAG_OVR     = (u8)0x41, /**< Overrun status flag */
  ADC_FLAG_AWDG    = (u8)0x40, /**< Analog WDG status */
  ADC_FLAG_AWDGS0  = (u8)0x10, /**< Analog channel 0 status */
  ADC_FLAG_AWDGS1  = (u8)0x11, /**< Analog channel 1 status */
  ADC_FLAG_AWDGS2  = (u8)0x12, /**< Analog channel 2 status */
  ADC_FLAG_AWDGS3  = (u8)0x13, /**< Analog channel 3 status */
  ADC_FLAG_AWDGS4  = (u8)0x14, /**< Analog channel 4 status */
  ADC_FLAG_AWDGS5  = (u8)0x15, /**< Analog channel 5 status */
  ADC_FLAG_AWDGS6  = (u8)0x16, /**< Analog channel 6 status */
  ADC_FLAG_AWDGS7  = (u8)0x17, /**< Analog channel 7 status */
  ADC_FLAG_AWDGS8  = (u8)0x18, /**< Analog channel 8  status*/
  ADC_FLAG_AWDGS9  = (u8)0x19, /**< Analog channel 9 status */
  ADC_FLAG_EOC     = (u8)0x80  /**< EOC falg */
}ADC_Flag_TypeDef;


/**
  * @brief ADC schmitt Trigger
  */
typedef enum {
  ADC_SCHMITTTRIG_CHANNEL0  = (u8)0x00, /**< Schmitt trigger disable on AIN0 */
  ADC_SCHMITTTRIG_CHANNEL1  = (u8)0x01, /**< Schmitt trigger disable on AIN1 */
  ADC_SCHMITTTRIG_CHANNEL2  = (u8)0x02, /**< Schmitt trigger disable on AIN2 */
  ADC_SCHMITTTRIG_CHANNEL3  = (u8)0x03, /**< Schmitt trigger disable on AIN3 */
  ADC_SCHMITTTRIG_CHANNEL4  = (u8)0x04, /**< Schmitt trigger disable on AIN4 */
  ADC_SCHMITTTRIG_CHANNEL5  = (u8)0x05, /**< Schmitt trigger disable on AIN5 */
  ADC_SCHMITTTRIG_CHANNEL6  = (u8)0x06, /**< Schmitt trigger disable on AIN6 */
  ADC_SCHMITTTRIG_CHANNEL7  = (u8)0x07, /**< Schmitt trigger disable on AIN7 */
  ADC_SCHMITTTRIG_CHANNEL8  = (u8)0x08, /**< Schmitt trigger disable on AIN8 */
  ADC_SCHMITTTRIG_CHANNEL9  = (u8)0x09, /**< Schmitt trigger disable on AIN9 */
  ADC_SCHMITTTRIG_CHANNEL10 = (u8)0x0A, /**< Schmitt trigger disable on AIN10 */
  ADC_SCHMITTTRIG_CHANNEL11 = (u8)0x0B, /**< Schmitt trigger disable on AIN11 */
  ADC_SCHMITTTRIG_CHANNEL12 = (u8)0x0C, /**< Schmitt trigger disable on AIN12 */
  ADC_SCHMITTTRIG_CHANNEL13 = (u8)0x0D, /**< Schmitt trigger disable on AIN13 */
  ADC_SCHMITTTRIG_CHANNEL14 = (u8)0x0E, /**< Schmitt trigger disable on AIN14 */
  ADC_SCHMITTTRIG_CHANNEL15 = (u8)0x0F, /**< Schmitt trigger disable on AIN15 */
  ADC_SCHMITTTRIG_ALL       = (u8)0x1F /**< Schmitt trigger disable on all channels */

} ADC_SchmittTrigg_TypeDef;

/**
  * @brief ADC conversion mode selection
  */

typedef enum {
  ADC_CONVERSIONMODE_SINGLE     = (u8)0x00, /**< Single conversion mode */
  ADC_CONVERSIONMODE_CONTINUOUS = (u8)0x01  /**< Continuous conversion mode */
} ADC_ConvMode_TypeDef;

/**
  * @brief ADC analog channel selection
  */


typedef enum {
  ADC_CHANNEL_0  = (u8)0x00, /**< Analog channel 0 */
  ADC_CHANNEL_1  = (u8)0x01, /**< Analog channel 1 */
  ADC_CHANNEL_2  = (u8)0x02, /**< Analog channel 2 */
  ADC_CHANNEL_3  = (u8)0x03, /**< Analog channel 3 */
  ADC_CHANNEL_4  = (u8)0x04, /**< Analog channel 4 */
  ADC_CHANNEL_5  = (u8)0x05, /**< Analog channel 5 */
  ADC_CHANNEL_6  = (u8)0x06, /**< Analog channel 6 */
  ADC_CHANNEL_7  = (u8)0x07, /**< Analog channel 7 */
  ADC_CHANNEL_8  = (u8)0x08, /**< Analog channel 8 */
  ADC_CHANNEL_9  = (u8)0x09, /**< Analog channel 9 */
  ADC_CHANNEL_10 = (u8)0x0A, /**< Analog channel 10 */
  ADC_CHANNEL_11 = (u8)0x0B, /**< Analog channel 11 */
  ADC_CHANNEL_12 = (u8)0x0C, /**< Analog channel 12 */
  ADC_CHANNEL_13 = (u8)0x0D, /**< Analog channel 13 */
  ADC_CHANNEL_14 = (u8)0x0E, /**< Analog channel 14 */
  ADC_CHANNEL_15 = (u8)0x0F  /**< Analog channel 15 */
} ADC_Channel_TypeDef;

/**
  * @}
  */

/* Exported constants --------------------------------------------------------*/

/* Exported macros ------------------------------------------------------------*/

/* Private macros ------------------------------------------------------------*/

/** @addtogroup ADC_Private_Macros
  * @brief Macros used by the assert function to check the different functions parameters.
  * @{
  */

/**
  * @brief Macro used by the assert function to check the different prescaler's values.
  */
#define IS_ADC_PRESSEL_OK(PRESCALER) (((PRESCALER) == ADC_PRESSEL_FCPU_D2) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D3) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D4) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D6) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D8) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D10) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D12) || \
                                      ((PRESCALER) == ADC_PRESSEL_FCPU_D18))

/**
  * @brief Macro used by the assert function to check the different external trigger values.
  */
#define IS_ADC_EXTTRIG_OK(EXTRIG) (((EXTRIG) == ADC_EXTTRIG_TIM) || \
                                   ((EXTRIG) == ADC_EXTTRIG_GPIO))

/**
  * @brief Macro used by the assert function to check the different alignement modes.
  */
#define IS_ADC_ALIGN_OK(ALIGN) (((ALIGN) == ADC_ALIGN_LEFT) || \
                                ((ALIGN) == ADC_ALIGN_RIGHT))

/**
  * @brief Macro used by the assert function to check the Interrupt source.
  */
#define IS_ADC_IT_OK(IT) (((IT) == ADC_IT_EOCITEN) || \
                          ((IT) == ADC_IT_AWDGITEN))

/**
  * @brief Macro used by the assert function to check the ADC Flag.
  */
#define IS_ADC_FLAG_OK(FLAG) (((FLAG) == ADC_FLAG_EOC)|| \
                              ((FLAG) == ADC_FLAG_OVR) || \
                              ((FLAG) == ADC_FLAG_AWDG) || \
                              ((FLAG) == ADC_FLAG_AWDGS0) || \
                              ((FLAG) == ADC_FLAG_AWDGS1) || \
                              ((FLAG) == ADC_FLAG_AWDGS2) || \
                              ((FLAG) == ADC_FLAG_AWDGS3) || \
                              ((FLAG) == ADC_FLAG_AWDGS4) || \
                              ((FLAG) == ADC_FLAG_AWDGS5) || \
                              ((FLAG) == ADC_FLAG_AWDGS6) || \
                              ((FLAG) == ADC_FLAG_AWDGS7) || \
                              ((FLAG) == ADC_FLAG_AWDGS8) || \
                              ((FLAG) == ADC_FLAG_AWDGS9))

/**
  * @brief Macro used by the assert function to check the ADC Flag.
  */
#define IS_ADC_ITPENDINGBIT_OK(ITPENDINGBIT) (((ITPENDINGBIT) == ADC_IT_EOC) || \
    ((ITPENDINGBIT) == ADC_IT_AWDG) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS0) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS1) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS2) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS3) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS4) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS5) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS6) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS7) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS8) || \
    ((ITPENDINGBIT) == ADC_IT_AWDGS9))

/**
  * @brief Macro used by the assert function to check the different schmitt trigger values.
  */
#define IS_ADC_SCHMITTTRIG_OK(SCHMITTTRIG) (((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL0) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL1) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL2) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL3) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL4) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL5) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL6) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL7) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL8) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL9) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL10) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL11) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL12) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL13) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL14) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_CHANNEL15) || \
    ((SCHMITTTRIG) == ADC_SCHMITTTRIG_ALL))

/**
  * @brief Macro used by the assert function to check the different conversion modes.
  */
#define IS_ADC_CONVERSIONMODE_OK(MODE) (((MODE) == ADC_CONVERSIONMODE_SINGLE) || \
                                        ((MODE) == ADC_CONVERSIONMODE_CONTINUOUS))

/**
  * @brief Macro used by the assert function to check the different channels values.
  */
#define IS_ADC_CHANNEL_OK(CHANNEL) (((CHANNEL) == ADC_CHANNEL_0) || \
                                    ((CHANNEL) == ADC_CHANNEL_1) || \
                                    ((CHANNEL) == ADC_CHANNEL_2) || \
                                    ((CHANNEL) == ADC_CHANNEL_3) || \
                                    ((CHANNEL) == ADC_CHANNEL_4) || \
                                    ((CHANNEL) == ADC_CHANNEL_5) || \
                                    ((CHANNEL) == ADC_CHANNEL_6) || \
                                    ((CHANNEL) == ADC_CHANNEL_7) || \
                                    ((CHANNEL) == ADC_CHANNEL_8) || \
                                    ((CHANNEL) == ADC_CHANNEL_9) || \
                                    ((CHANNEL) == ADC_CHANNEL_10) || \
                                    ((CHANNEL) == ADC_CHANNEL_11) || \
                                    ((CHANNEL) == ADC_CHANNEL_12) || \
                                    ((CHANNEL) == ADC_CHANNEL_13) || \
                                    ((CHANNEL) == ADC_CHANNEL_14) || \
                                    ((CHANNEL) == ADC_CHANNEL_15))

/**
  * @brief Macro used by the assert function to check the possible buffer values.
  */
#define IS_ADC_BUFFER_OK(BUFFER) (((BUFFER) >= 0) && ((BUFFER) <= 9))

/**
  * @}
  */

/* Exported functions ------------------------------------------------------- */

/** @addtogroup ADC_Exported_Functions
  * @{
  */
void ADC_DeInit(void);
void ADC_Init(ADC_ConvMode_TypeDef ADC_ConversionMode, ADC_Channel_TypeDef ADC_Channel, ADC_PresSel_TypeDef ADC_PrescalerSelection, ADC_ExtTrig_TypeDef ADC_ExtTrigger, FunctionalState ADC_ExtTrigState, ADC_Align_TypeDef ADC_Align, ADC_SchmittTrigg_TypeDef ADC_SchmittTriggerChannel, FunctionalState ADC_SchmittTriggerState);
void ADC_Cmd(FunctionalState NewState);
void ADC_ScanModeCmd(FunctionalState NewState);
void ADC_DataBufferCmd(FunctionalState NewState);
void ADC_ITConfig(ADC_IT_TypeDef ADC_IT, FunctionalState ADC_ITEnable);
void ADC_PrescalerConfig(ADC_PresSel_TypeDef ADC_Prescaler);
void ADC_SchmittTriggerConfig(ADC_SchmittTrigg_TypeDef ADC_SchmittTriggerChannel, FunctionalState ADC_SchmittTriggerState);
void ADC_ConversionConfig(ADC_ConvMode_TypeDef ADC_ConversionMode, ADC_Channel_TypeDef ADC_Channel, ADC_Align_TypeDef ADC_Align);
void ADC_ExternalTriggerConfig(ADC_ExtTrig_TypeDef ADC_ExtTrigger, FunctionalState ADC_ExtTrigState);
void ADC_AWDGChannelConfig(ADC_Channel_TypeDef Channel, FunctionalState NewState);
void ADC_StartConversion(void);
u16 ADC_GetConversionValue(void);
void ADC_SetHighThreshold(u16 Threshold);
void ADC_SetLowThreshold(u16 Threshold);
u16 ADC_GetBufferValue(u8 Buffer);
FlagStatus ADC_GetAWDGChannelStatus(ADC_Channel_TypeDef Channel);
FlagStatus ADC_GetFlagStatus(ADC_Flag_TypeDef Flag);
void ADC_ClearFlag(ADC_Flag_TypeDef Flag);
ITStatus ADC_GetITStatus(ADC_IT_TypeDef ITPendingBit);
void ADC_ClearITPendingBit(ADC_IT_TypeDef ITPendingBit);
/**
  * @}
  */

#endif /* __STM8S_ADC_H */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
