/**
  ********************************************************************************
  * @file stm8s_uart1.h
  * @brief This file contains all functions prototypes and macros for the UART1 peripheral.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __STM8S_UART1_H
#define __STM8S_UART1_H

/* Includes ------------------------------------------------------------------*/
#include "stm8s_map.h"

/* Exported types ------------------------------------------------------------*/

/** @addtogroup UART1_Exported_Types
  * @{
  */

/**
  * @brief UART1 WakeUP Modes
  */
typedef enum { UART1_WAKEUP_IDLELINE      = (u8)0x00,  /**< 0x01 Idle Line wake up*/
               UART1_WAKEUP_ADDRESSMARK   = (u8)0x08   /**< 0x02 Address Mark wake up*/
             } UART1_WakeUp_TypeDef;

/**
  * @brief UART1 LIN Break detection length possible values
  */
typedef enum { UART1_LINBREAKDETECTIONLENGTH_10BITS = (u8)0x00, /**< 10 bits Lin Break detection            */
               UART1_LINBREAKDETECTIONLENGTH_11BITS = (u8)0x01  /**< 11 bits Lin Break detection          */
             } UART1_LINBreakDetectionLength_TypeDef;


/**
  * @brief UART1 stop bits possible values
  */
typedef enum { UART1_STOPBITS_1  = (u8)0x00,  /**< One stop bit is  transmitted at the end of frame*/
               UART1_STOPBITS_2  = (u8)0x20   /**< Two stop bits are  transmitted at the end of frame*/
             } UART1_StopBits_TypeDef;

/**
  * @brief UART1 parity possible values
  */
typedef enum { UART1_PARITY_NO    = (u8)0x00,    /**< No Parity*/
               UART1_PARITY_EVEN  = (u8)0x04,    /**< Even Parity*/
               UART1_PARITY_ODD   = (u8)0x06     /**< Odd Parity*/
             } UART1_Parity_TypeDef;

/**
  * @brief UART1 Word length possible values
  */
typedef enum { UART1_WORDLENGTH_8D = (u8)0x00,    /**< 0x00 8 bits Data*/
               UART1_WORDLENGTH_9D = (u8)0x10     /**< 0x10 9 bits Data*/
             } UART1_WordLength_TypeDef;

/**
  * @brief UART1 Mode Transmit/Receive possible values
  */
typedef enum { UART1_MODE_RX_ENABLE    = (u8)0x08,  /**< 0x08 Receive Enable*/
               UART1_MODE_TX_ENABLE    = (u8)0x04,  /**< 0x04 Transmit Enable*/
               UART1_MODE_TX_DISABLE   = (u8)0x80,  /**< 0x80 Receive Enable*/
               UART1_MODE_RX_DISABLE   = (u8)0x40,  /**< 0x40 Single-wire Half-duplex mode*/
               UART1_MODE_TXRX_ENABLE  = (u8)0x0C   /**< 0x0C Receive Enable and Transmit enable*/
             } UART1_Mode_TypeDef;

/**
  * @brief UART1 Mode possible values
  */
typedef enum { UART1_LIN_MODE_MASTER  = (u8)0x00, /**<  LIN Master Mode*/
               UART1_LIN_MODE_SLAVE   = (u8)0x01  /**<  LIN Slave Mode*/
             } UART1_LinMode_TypeDef;
/**
  * @brief UART1 automatic resynchronisation possible values
  */
typedef enum { UART1_LIN_AUTOSYNC_DISABLE   = (u8)0x00,  /**< LIN Autosynchronization Disable*/
               UART1_LIN_AUTOSYNC_ENABLE    = (u8)0x01   /**< LIN Autosynchronization Enable*/
             } UART1_LinAutosync_TypeDef;
/**
  * @brief UART1 Divider Update Method possible values
  */
typedef enum { UART1_LIN_DIVUP_LBRR1    = (u8)0x00, /**<  LIN LDIV is updated as soon as LBRR1 is written*/
               UART1_LIN_DIVUP_NEXTRXNE = (u8)0x01  /**<  LIN LDIV is updated at the next received character*/
             } UART1_LinDivUp_TypeDef;


/**
  * @brief UART1 Flag possible values
  */
typedef enum
{
  UART1_FLAG_TXE         = (u16)0x0080, /*!< Transmit Data Register Empty flag */
  UART1_FLAG_TC          = (u16)0x0040, /*!< Transmission Complete flag */
  UART1_FLAG_RXNE         = (u16)0x0020, /*!< Read Data Register Not Empty flag */
  UART1_FLAG_IDLE         = (u16)0x0010, /*!< Idle line detected flag */
  UART1_FLAG_ORE_LHE     = (u16)0x0008, /*!< OverRun error flag */
  UART1_FLAG_NE          = (u16)0x0004, /*!< Noise error flag */
  UART1_FLAG_FE           = (u16)0x0002, /*!< Framing Error flag */
  UART1_FLAG_PE          = (u16)0x0001, /*!< Parity Error flag */
  UART1_FLAG_SBK          = (u16)0x0101,  /**< Send Break Complete interrupt flag */
  UART1_FLAG_LBD          = (u16)0x0210, /**< LIN Break Detection Flag           */
  UART1_FLAG_LHD          = (u16)0x0302, /**< LIN Header Detection Flag*/
  UART1_FLAG_LSF          = (u16)0x0301  /**< LIN Sync Field Flag*/
} UART1_Flag_TypeDef;

/**
  * @brief UART1_ITPENDINGBIT possible values
  * Elements values convention: 0xZYX
  * X: Position of the corresponding Interrupt
  * Y: ITPENDINGBIT position
  * Z: Register index
  */
typedef enum { UART1_IT_TXE        = (u16)0x0277, /**< Transmit interrupt */
               UART1_IT_TC         = (u16)0x0266, /**< Transmission Complete interrupt */
               UART1_IT_RXNE       = (u16)0x0255, /**< Data Register Not Empty interrupt */
               UART1_IT_IDLE       = (u16)0x0244, /**< Idle line detected interrupt */
               UART1_IT_ORE        = (u16)0x0235, /**< OverRun error interrupt */
               UART1_IT_PE         = (u16)0x0100, /**< Parity Error interrupt */
               UART1_IT_LBD       = (u16)0x0346, /**< LIN Break Detection interrupt */
               UART1_IT_LHD       = (u16)0x0412, /**< LIN Header Detection interrupt*/
               UART1_IT_RXNE_ORE   = (u16)0x0205  /*!< Receive/Overrun interrupt */
             } UART1_IT_TypeDef;


/**
  * @}
  */

/* Exported constants --------------------------------------------------------*/
/* Exported macros ------------------------------------------------------------*/

/* Private macros ------------------------------------------------------------*/

/** @addtogroup UART1_Private_Macros
  * @{
  */

/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the FLAGs
  */
#define IS_UART1_FLAG_OK(Flag) \
  (((Flag) == UART1_FLAG_TXE) || \
   ((Flag) == UART1_FLAG_TC)  || \
   ((Flag) == UART1_FLAG_RXNE) || \
   ((Flag) == UART1_FLAG_IDLE) || \
   ((Flag) == UART1_FLAG_ORE_LHE) || \
   ((Flag) == UART1_FLAG_NE) || \
   ((Flag) == UART1_FLAG_FE) || \
   ((Flag) == UART1_FLAG_PE) || \
   ((Flag) == UART1_FLAG_SBK) || \
   ((Flag) == UART1_FLAG_LSF) || \
   ((Flag) == UART1_FLAG_LHD) || \
   ((Flag) == UART1_FLAG_LBD))


/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the FLAGs that can be cleared by writing 0
  */
#define IS_UART1_CLEAR_FLAG_OK(Flag) \
  (((Flag) == UART1_FLAG_RXNE) || \
   ((Flag) == UART1_FLAG_LHD) || \
   ((Flag) == UART1_FLAG_LSF) || \
   ((Flag) == UART1_FLAG_LBD))

/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the Interrupts
  */

#define IS_UART1_CONFIG_IT_OK(Interrupt) \
  (((Interrupt) == UART1_IT_PE) || \
   ((Interrupt) == UART1_IT_TXE) || \
   ((Interrupt) == UART1_IT_TC) || \
   ((Interrupt) == UART1_IT_RXNE_ORE ) || \
   ((Interrupt) == UART1_IT_IDLE) || \
   ((Interrupt) == UART1_IT_LHD) || \
   ((Interrupt) == UART1_IT_LBD))

/**
  * @brief Macro used by the assert function in order to check the different sensitivity values for the pending bit
  */
#define IS_UART1_GET_IT_OK(ITPendingBit) \
  (((ITPendingBit) == UART1_IT_TXE)  || \
   ((ITPendingBit) == UART1_IT_TC)   || \
   ((ITPendingBit) == UART1_IT_RXNE) || \
   ((ITPendingBit) == UART1_IT_IDLE) || \
   ((ITPendingBit) == UART1_IT_ORE)  || \
   ((ITPendingBit) == UART1_IT_LBD)  || \
   ((ITPendingBit) == UART1_IT_LHD)  || \
   ((ITPendingBit) == UART1_IT_PE))

/**
  * @brief Macro used by the assert function in order to check the different sensitivity values for the pending bit that can be cleared by writing 0
  */
#define IS_UART1_CLEAR_IT_OK(ITPendingBit) \
  (((ITPendingBit) == UART1_IT_RXNE) || \
   ((ITPendingBit) == UART1_IT_LHD) || \
   ((ITPendingBit) == UART1_IT_LBD))

/**
 * @brief Macro used by the assert_param function in order to check the different sensitivity values for the MODEs
 */
#define IS_UART1_MODE_OK(Mode) \
  (((Mode) == (u8)UART1_MODE_RX_ENABLE) || \
   ((Mode) == (u8)UART1_MODE_RX_DISABLE) || \
   ((Mode) == (u8)UART1_MODE_TX_ENABLE) || \
   ((Mode) == (u8)UART1_MODE_TX_DISABLE) || \
   ((Mode) == (u8)UART1_MODE_TXRX_ENABLE) || \
   ((Mode) == (u8)((u8)UART1_MODE_TX_ENABLE|(u8)UART1_MODE_RX_ENABLE)) || \
   ((Mode) == (u8)((u8)UART1_MODE_TX_ENABLE|(u8)UART1_MODE_RX_DISABLE)) || \
   ((Mode) == (u8)((u8)UART1_MODE_TX_DISABLE|(u8)UART1_MODE_RX_DISABLE)) || \
   ((Mode) == (u8)((u8)UART1_MODE_TX_DISABLE|(u8)UART1_MODE_RX_ENABLE)))

/**
 * @brief Macro used by the assert_param function in order to check the different sensitivity values for the WordLengths
 */
#define IS_UART1_WORDLENGTH_OK(WordLength) \
  (((WordLength) == UART1_WORDLENGTH_8D) || \
   ((WordLength) == UART1_WORDLENGTH_9D))


/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the WakeUps
  */
#define IS_UART1_WAKEUP_OK(WakeUpMode) \
  (((WakeUpMode) == UART1_WAKEUP_IDLELINE) || \
   ((WakeUpMode) == UART1_WAKEUP_ADDRESSMARK))

/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the LINBreakDetectionLengths
  */
#define IS_UART1_LINBREAKDETECTIONLENGTH_OK(LINBreakDetectionLengths) \
  (((LINBreakDetectionLengths) == UART1_LINBREAKDETECTIONLENGTH_10BITS) || \
   ((LINBreakDetectionLengths) == UART1_LINBREAKDETECTIONLENGTH_11BITS))

/**
  * @brief Macro used by the assert_param function in order to check the different sensitivity values for the UART1_StopBits
  */
#define IS_UART1_STOPBITS_OK(StopBit) \
  (((StopBit) == UART1_STOPBITS_1) || \
   ((StopBit) == UART1_STOPBITS_2))

/**
 * @brief Macro used by the assert_param function in order to check the different sensitivity values for the Paritys
 */
#define IS_UART1_PARITY_OK(Parity) \
  (((Parity) == UART1_PARITY_NO) || \
   ((Parity) == UART1_PARITY_EVEN) || \
   ((Parity) == UART1_PARITY_ODD ))

/**
 * @brief Macro used by the assert_param function in order to check the maximum baudrate value
 */
#define IS_UART1_BAUDRATE_OK(NUM) ((NUM) <= (u32)625000)

/**
 * @brief Macro used by the assert_param function in order to check the address of the UART1 or UART node
 */
#define UART1_ADDRESS_MAX ((u8)16)
#define IS_UART1_Address_OK(Node) (((Node) < UART1_ADDRESS_MAX))

/**
 * @brief Macro used by the assert_param function in order to check the LIN mode
 */
#define IS_UART1_SLAVE_OK(Mode) \
  (((Mode) == UART1_LIN_MODE_MASTER) || \
   ((Mode) == UART1_LIN_MODE_SLAVE))

/**
 * @brief Macro used by the assert_param function in order to check the LIN automatic resynchronization mode
 */
#define IS_UART1_AUTOSYNC_OK(AutosyncMode) \
  (((AutosyncMode) ==  UART1_LIN_AUTOSYNC_ENABLE) || \
   ((AutosyncMode) == UART1_LIN_AUTOSYNC_DISABLE))

/**
 * @brief Macro used by the assert_param function in order to check the LIN divider update method
 */
#define IS_UART1_DIVUP_OK(DivupMethode) \
  (((DivupMethode) == UART1_LIN_DIVUP_LBRR1) || \
   ((DivupMethode) == UART1_LIN_DIVUP_NEXTRXNE))

/**
  * @}
  */

/* Exported functions ------------------------------------------------------- */

/** @addtogroup UART1_Exported_Functions
  * @{
  */

void UART1_DeInit(void);
void UART1_Init(u32 BaudRate, UART1_WordLength_TypeDef WordLength, UART1_StopBits_TypeDef StopBits, UART1_Parity_TypeDef Parity, UART1_Mode_TypeDef Mode);
void UART1_Cmd(FunctionalState NewState);
void UART1_ITConfig(UART1_IT_TypeDef UART1_IT, FunctionalState NewState);
void UART1_LINBreakDetectionConfig(UART1_LINBreakDetectionLength_TypeDef UART1_LINBreakDetectionLength);
void UART1_LINConfig(UART1_LinMode_TypeDef UART1_Mode, UART1_LinAutosync_TypeDef UART1_Autosync, UART1_LinDivUp_TypeDef UART1_DivUp);
void UART1_LINCmd(FunctionalState NewState);
void UART1_ReceiverWakeUpCmd(FunctionalState NewState);
void UART1_WakeUpConfig( UART1_WakeUp_TypeDef UART1_WakeUp);
u8 UART1_ReceiveData8(void);
u16 UART1_ReceiveData9(void);
void UART1_SendData8(u8 Data);
void UART1_SendData9(u16 Data);
void UART1_SendBreak(void);
void UART1_SetAddress(u8 UART1_Address);

FlagStatus UART1_GetFlagStatus(UART1_Flag_TypeDef UART1_FLAG);
void UART1_ClearFlag(UART1_Flag_TypeDef UART1_FLAG);
ITStatus UART1_GetITStatus(UART1_IT_TypeDef UART1_IT);
void UART1_ClearITPendingBit(UART1_IT_TypeDef UART1_IT);
/**
  * @}
  */

#endif /* __STM8S_UART1_H */

/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
