/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : led_dimmer.c
* Author             : EMMA team Prague
* Date First Issued  : 12/21/2007
* Description        : This file contains all the functions prototypes for the
*                      lcd software driver.
********************************************************************************
* History:
* 12/21/2007: V0.0
*******************************************************************************/
/*******************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
/* Define to prevent recursive inclusion -------------------------------------*/
#include "stm8s_lib.h"
#include "led_dimmer.h"
//#include "stm32f10x_systick.h"
//#include "stm32f10x_nvic.h"
//#include "stm32f10x_lib.h"
#include <stdlib.h>

#include "table_generator.h"

#define SPI1_DR_Address   (SPI1_BASE + 0x000C)  //computed by Ludek Holoubek 

unsigned int actual_streamSize = 1;
int actual_PWMdepth;

unsigned char *actual_table_start;
unsigned char *actual_table_key_start;
int actual_table_size;

unsigned char *new_table_start;
unsigned char *new_table_key_start;
int new_table_size;

unsigned char *released_table_start;
unsigned char *released_table_key_start;
int released_table_size;


int new_table_not_changed_yet_flag;

void fillDriver(int LEDcount){
  unsigned short streamSizeToTest;
  int i;
  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;
  
  for(i = 0; i < streamSizeToTest; i++){
    SPI->DR = 0x00;
    while ((SPI->SR & SPI_SR_TXE) == 0);
  }
}  

int setup(int LEDcount, int PWMdepth, int requestedRefreshRate){ //set up refresh rate, configure interrupts and DMA
  float TotalTime, SystickTime;
  long PreloadValue;
  TotalTime = (2.25 + 0.055 * LEDcount) * 0.000001;  //this is valid for about 10MHz of SPI
  SystickTime = 1.0 / ((float)requestedRefreshRate * (float)PWMdepth);

  if(SystickTime < TotalTime)  //the values requested cannot be reached
    return ERROR;
  
	//the main frequenci is 24000000 Hz and no prescaller for Timer
  PreloadValue = 24000000l / (requestedRefreshRate * PWMdepth);

  TIM1_TimeBaseInit(0, TIM1_COUNTERMODE_UP, PreloadValue, 0);
  TIM1_Cmd(DISABLE);
  TIM1_ITConfig(TIM1_IT_UPDATE, ENABLE);
  enableInterrupts();

  actual_streamSize = LEDcount / 8;
  if(actual_streamSize*8 < LEDcount)
    actual_streamSize++;  
  
  released_table_start     = new_table_start     = actual_table_start     = NULL;
  released_table_key_start = new_table_key_start = actual_table_key_start = NULL;

  return SUCCESS;
}

unsigned char DATAIN;

unsigned char error_detection_DMX(unsigned char *LEDmapIN, int LEDcount){
  unsigned short i, y, X, eFlag;
  unsigned short streamSizeToTest;

  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;  
  
  stop_dimmer();
  LED_driver_OutDisable_All_Off();//LED_driver_OutDisable(1); LED_driver_OutDisable(2);

  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();
  
  for(i = 0; i < 6; i++){
    SPI->DR =  0xFF;
    while ((SPI->SR & SPI_SR_TXE) == 0);
  }

  GPIO_WriteLow(LE_PORT, LE_PIN); //FAST_LE_LOW();
  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();
  GPIO_WriteLow(LE_PORT, LE_PIN); //FAST_LE_LOW();
  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();
  
	SPI_Cmd(DISABLE);
  GPIO_WriteHigh(SPI_PORT, SPI_MOSI_PIN); 
	
  SPI_CLK_HIGH();
  SPI_CLK_LOW();

  GPIO_WriteLow(DM_PORT, DM_PIN); //entering diagnostic mode

      SPI_CLK_LOW();SPI_CLK_LOW();SPI_CLK_LOW();SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();

  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);

      SPI_CLK_LOW();SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();

  for(i=0; i<3; i++)  
      X = 10+i+y;    

  SPI_CLK_HIGH();
  SPI_CLK_LOW();

    SPI_CLK_LOW();  SPI_CLK_LOW();
  
  LED_driver_OutDisable_All_Off();//LED_driver_OutDisable(1); LED_driver_OutDisable(2);  

  GPIO_WriteHigh(DM_PORT, DM_PIN);  //leaving diagnostic mode  

  SPI_Cmd(ENABLE);

  eFlag = 0;
  DATAIN = SPI_ReceiveData();  //clear the input buffer flag
  SPI->DR =  0x00;
  for(i = 0; i < (streamSizeToTest); i++){
    while ((SPI->SR & SPI_SR_TXE) == 0);
    while ((SPI->SR & SPI_SR_RXNE) == 0);
    DATAIN = SPI_ReceiveData();  
    //DATAIN = SPI->DR;
    SPI->DR =  0x00;
    for(y = 0; y<8; y++)
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)] = 1;
      else{
        LEDmapIN[(i*8+y)] = 0;
        eFlag = 1;        
      }
  }
 
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  //MAKE IT CORRECT !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!  

  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();   //new
  GPIO_WriteLow(LE_PORT, LE_PIN); //FAST_LE_LOW();    //new

  return eFlag;
}

unsigned char error_detection_LE_OE(unsigned char *LEDmapIN, int LEDcount){

  unsigned int i, y, X, eFlag;
  unsigned short streamSizeToTest;

  stop_dimmer();

  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);

  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();

  streamSizeToTest = LEDcount / 8;
  if(streamSizeToTest*8 < LEDcount)
    streamSizeToTest++;
  
  for(i = 0; i < streamSizeToTest; i++){
    SPI->DR =  0xFF;
    while ((SPI->SR & SPI_SR_TXE) == 0);
  }
  
  SPI_Cmd(DISABLE);
  GPIO_WriteHigh(SPI_PORT, SPI_MOSI_PIN); 

  //start point
  GPIO_WriteLow(LE_PORT, LE_PIN); //LE=0
  SPI_CLK_LOW();
  //start point
  //sequence
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  GPIO_WriteLow(LE_PORT, LE_PIN);  //FAST_LE_low();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  //sequence - we have entered the test mode.
 
  for(i = 0; i < 48; i++){  //filling of 48 ones in to the driver
    SPI_CLK_HIGH();
    SPI_CLK_LOW();
  }
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();

  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH(); //latching of 48 ones to the driver
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();
  GPIO_WriteLow(LE_PORT, LE_PIN);  //FAST_LE_low();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
    SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();

  GPIO_WriteLow(LE_PORT, LE_PIN); //FAST_LE_LOW();

  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);  //all the LED must be on for the test
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();


  for(i=0; i<10; i++)  
//    for(y=0; y<10; y++)
      X = 10+i+y;    


  SPI_CLK_HIGH();
  SPI_CLK_LOW();
//  SPI_CLK_HIGH();
//  SPI_CLK_LOW();
  
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);  //end of the measurement on the LEDs

  SPI_Cmd(ENABLE);

  eFlag = 0;
  DATAIN = SPI_ReceiveData();  //clear the input buffer flag
  for(i = 0; i < (streamSizeToTest); i++){
    SPI->DR =  0x00;
    while ((SPI->SR & SPI_SR_TXE) == 0);
		while ((SPI->SR & SPI_SR_RXNE) == 0);
    DATAIN = SPI->DR;
    for(y = 0; y<8; y++)
      if((DATAIN << y) & 0x80)
        LEDmapIN[(i*8+y)] = 1;
      else{
        LEDmapIN[(i*8+y)] = 0;
        eFlag = 1;        
      }
  }

  GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH(); //new
  GPIO_WriteLow(LE_PORT, LE_PIN); //FAST_LE_LOW(); //new
 
  SPI_Cmd(DISABLE);
      
  //end point
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutEnable_All_On(); //LED_driver_OutEnable(1); LED_driver_OutEnable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  LED_driver_OutDisable_All_Off(); //LED_driver_OutDisable(1); LED_driver_OutDisable(2);
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  SPI_CLK_HIGH();
  SPI_CLK_LOW();
  //end point
  
  SPI_Cmd(ENABLE);
  return eFlag;
}

void start_dimmer(void){      //enable main interrupt and start sending data to SPI
  TIM1_Cmd(ENABLE);
}
  
void stop_dimmer(void){       //disable main interrupt and stop sending data to SPI
  TIM1_Cmd(DISABLE);
}

void LED_driver_OutEnable_All_On(void){   //enable OE
  GPIO_WriteLow(OE1_PORT, OE1B_PIN); //Blue  OE1B
  GPIO_WriteLow(OE1_PORT, OE1G_PIN); //Green OE1G
  GPIO_WriteLow(OE1_PORT, OE1R_PIN); //Red   OE1R
  GPIO_WriteLow(OE2_PORT, OE2B_PIN); //Blue  OE2B
  GPIO_WriteLow(OE2_PORT, OE2G_PIN); //Green OE2G
  GPIO_WriteLow(OE2_PORT, OE2R_PIN); //Red   OE2R
}

void LED_driver_OutDisable_All_Off(void){   //disable signal OE
  GPIO_WriteHigh(OE1_PORT, OE1B_PIN); //Blue  OE1B
  GPIO_WriteHigh(OE1_PORT, OE1G_PIN); //Green OE1G
  GPIO_WriteHigh(OE1_PORT, OE1R_PIN); //Red   OE1R
  GPIO_WriteHigh(OE2_PORT, OE2B_PIN); //Blue  OE2B
  GPIO_WriteHigh(OE2_PORT, OE2G_PIN); //Green OE2G
  GPIO_WriteHigh(OE2_PORT, OE2R_PIN); //Red   OE2R
}

void LED_driver_OutEnable(unsigned char which, unsigned char RGBchannel){   //enable OE
  if(which == 1)
  {
    if(RGBchannel & 0x01) GPIO_WriteLow(OE1_PORT, OE1B_PIN); //Blue  OE1B
    if(RGBchannel & 0x02) GPIO_WriteLow(OE1_PORT, OE1G_PIN); //Green OE1G
    if(RGBchannel & 0x04) GPIO_WriteLow(OE1_PORT, OE1R_PIN); //Red   OE1R
  }
  if(which == 2)
  {
    if(RGBchannel & 0x01) GPIO_WriteLow(OE2_PORT, OE2B_PIN); //Blue  OE2B
    if(RGBchannel & 0x02) GPIO_WriteLow(OE2_PORT, OE2G_PIN);  //Green OE2G
    if(RGBchannel & 0x04) GPIO_WriteLow(OE2_PORT, OE2R_PIN);  //Red   OE2R
  }
}

void LED_driver_OutDisable(unsigned char which, unsigned char RGBchannel){   //disable signal OE
  if(which == 1)
  {
    if(RGBchannel & 0x01) GPIO_WriteHigh(OE1_PORT, OE1B_PIN); //Blue  OE1B
    if(RGBchannel & 0x02) GPIO_WriteHigh(OE1_PORT, OE1G_PIN); //Green OE1G
    if(RGBchannel & 0x04) GPIO_WriteHigh(OE1_PORT, OE1R_PIN); //Red   OE1R
  }
  if(which == 2)
  {
    if(RGBchannel & 0x01) GPIO_WriteHigh(OE2_PORT, OE2B_PIN); //Blue  OE2B
    if(RGBchannel & 0x02) GPIO_WriteHigh(OE2_PORT, OE2G_PIN);  //Green OE2G
    if(RGBchannel & 0x04) GPIO_WriteHigh(OE2_PORT, OE2R_PIN);  //Red   OE2R
  }
}

void SPI_CLK_LOW(void){
  GPIO_WriteLow(SPI_PORT, SPI_CLK_PIN);
}

void SPI_CLK_HIGH(void){
  GPIO_WriteHigh(SPI_PORT, SPI_CLK_PIN);
}

void use_new_table_immediately(unsigned char *table, unsigned char *tableKey, int table_size){ //exchange table(SPI data) not preventing glitch,
  released_table_start     = actual_table_start;
  released_table_key_start = actual_table_key_start;
  released_table_size      = actual_table_size;

  actual_table_start     = table;
  actual_table_key_start = tableKey;
  actual_table_size      = table_size;
  
  new_table_not_changed_yet_flag = 0;
}

void use_new_table_carefully(unsigned char *table, unsigned char *tableKey, int table_size){
  new_table_not_changed_yet_flag = 1; //exchange table(SPI data) preventing glitch, in right time

  released_table_start     = actual_table_start;
  released_table_key_start = actual_table_key_start;
  released_table_size      = actual_table_size;

  new_table_start     = table;
  new_table_key_start = tableKey;
  new_table_size      = table_size;
}
  
int new_table_not_changed_yet(void){ //true till right time for table not reached
  return new_table_not_changed_yet_flag;
}
  
int generateReducedLookUpTable(unsigned char *LEDmapIN, int LEDcount, int PWMdepth, unsigned char **tableIN, unsigned char **tableKeyIN, int *table_sizeIN){
//  *tableIN = generateFullLookUpTable(LEDmapIN, LEDcount, PWMdepth);
//  *table_sizeIN = 256;
  performGenerateReducedLookUpTable(LEDmapIN, LEDcount, PWMdepth, tableIN, tableKeyIN, table_sizeIN);

  if((*tableIN)&&(*tableKeyIN))
    return SUCCESS;
  else
    return ERROR;
}

void removeLookUpTableInUse(void){
  if(actual_table_start)
    free(actual_table_start);
  if(actual_table_start)
    free(actual_table_start);
}

void removeLookUpTableReleased(void){
  if(released_table_start)
    free(released_table_start);
  if(released_table_key_start)
    free(released_table_key_start);
}

void RCC_Configuration(void)
{
CLK_DeInit();
CLK_HSICmd(ENABLE);
CLK_HSIPrescalerConfig(CLK_PRESCALER_HSIDIV1);
CLK_SYSCLKConfig(CLK_PRESCALER_CPUDIV1);
CLK_ClockSwitchConfig(CLK_SWITCHMODE_MANUAL, CLK_SOURCE_HSI, DISABLE, CLK_CURRENTCLOCKSTATE_ENABLE);
//CLK_PeripheralClockConfig(CLK_Peripheral_TypeDef CLK_Peripheral, FunctionalState CLK_NewState);
//CLK_SWIMConfig(CLK_SWIMDivider_TypeDef CLK_SWIMDivider);
CLK_ClockSwitchCmd(ENABLE);

CLK_CCOConfig(CLK_OUTPUT_CPU);
}

void NVIC_Configuration(void)
{
}

/*
u32 getSemiRnd(void){
  return SysTick_GetCounter();
}
*/

void SPI_GPIO_Init(void)
{
  /* OE-output enable, DM - diagnostic mode, LE - latch enable, SPI*/
  GPIO_WriteHigh(GPIOB, OE1B_PIN);  
	GPIO_WriteHigh(GPIOB, OE1G_PIN);
  GPIO_WriteHigh(GPIOB, OE1R_PIN);  
  GPIO_WriteHigh(GPIOB, DM_PIN);
  GPIO_Init(GPIOB, (OE1B_PIN | OE1G_PIN | OE1R_PIN | DM_PIN), GPIO_MODE_OUT_PP_HIGH_FAST);
  GPIO_WriteHigh(GPIOB, OE1B_PIN);  
	GPIO_WriteHigh(GPIOB, OE1G_PIN);
  GPIO_WriteHigh(GPIOB, OE1R_PIN);  
  GPIO_WriteHigh(GPIOB, DM_PIN);
  //
  GPIO_WriteHigh(GPIOC, OE2B_PIN);
  GPIO_WriteHigh(GPIOC, OE2G_PIN);  
	GPIO_WriteHigh(GPIOC, OE2R_PIN);
  GPIO_WriteHigh(GPIOC, LE_PIN);
  GPIO_Init(GPIOC, (OE2B_PIN | OE2G_PIN | OE2R_PIN | LE_PIN 
	                | SPI_CLK_PIN | SPI_MOSI_PIN), GPIO_MODE_OUT_PP_HIGH_FAST);
  GPIO_Init(GPIOC, (SPI_MISO_PIN), GPIO_MODE_IN_FL_NO_IT);
  GPIO_WriteHigh(GPIOC, OE2B_PIN);
  GPIO_WriteHigh(GPIOC, OE2G_PIN);  
	GPIO_WriteHigh(GPIOC, OE2R_PIN);
  GPIO_WriteHigh(GPIOC, LE_PIN);

  /* SPI1 configuration */ 
  SPI_DeInit();
  SPI_Init(SPI_FIRSTBIT_MSB, SPI_BAUDRATEPRESCALER_2, SPI_MODE_MASTER,
	         SPI_CLOCKPOLARITY_HIGH, SPI_CLOCKPHASE_2EDGE, SPI_DATADIRECTION_2LINES_FULLDUPLEX,
					 SPI_NSS_SOFT, 0x07);
	SPI_Cmd(ENABLE);	
}

