/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : led_dimmer.h
* Author             : EMMA team Prague
* Date First Issued  : 12/21/2007
* Description        : This file contains all the functions prototypes for the
*                      lcd software driver.
********************************************************************************
* History:
* 12/21/2007: V0.0
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __LED_DIMMER_H
#define __LED_DIMMER_H


#define OE1_PORT (GPIOB)  //--------
#define OE1B_PIN (GPIO_PIN_2)
#define OE1G_PIN (GPIO_PIN_1)
#define OE1R_PIN (GPIO_PIN_0)

#define DM_PORT (GPIOB)  //-------
#define DM_PIN  (GPIO_PIN_3)

#define OE2_PORT (GPIOC)  //--------
#define OE2B_PIN (GPIO_PIN_2)
#define OE2G_PIN (GPIO_PIN_1)
#define OE2R_PIN (GPIO_PIN_0)

#define LE_PORT (GPIOC)  //--------
#define LE_PIN  (GPIO_PIN_3)

#define SPI_PORT     (GPIOC)  //-------
#define SPI_CLK_PIN  (GPIO_PIN_5)
#define SPI_MOSI_PIN (GPIO_PIN_6)
#define SPI_MISO_PIN (GPIO_PIN_7)


//#include "stm32f10x_type.h"

#define REDchannel   0x04
#define GREENchannel 0x02
#define BLUEchannel  0x01

#define PWM_8_bit 256
#define PWM_9_bit 512
#define PWM_10_bit 1024
#define PWM_11_bit 2048
#define PWM_12_bit 4096

int setup(int LEDcount, int PWMdepth, int requestedRefreshRate); //set up refresh rate, configure interrupts and DMA
//If STM8 is used, if you have less that 8 LEDs, specify allways 8 LEDs or more, minimal depth is 8-bit.
                                                                 //returns refresh rate or zero as a fault
//unsigned char error_detection_DM(unsigned char *LEDmapIN, int LEDcount); //detect defect leds and LEDmapIN will have zeroes on the defect position. return 1 if error occured.
                                                                         //uses DM signal to enter the test mode
unsigned char error_detection_DMX(unsigned char *LEDmapIN, int LEDcount); //detect defect leds and LEDmapIN will have zeroes on the defect position. return 1 if error occured.
                                                                         //uses DM signal to enter the test mode
unsigned char error_detection_LE_OE(unsigned char *LEDmapIN, int LEDcount); //detect defect leds and LEDmapIN will have zeroes on the defect position. return 1 if error occured.
                                                                            //uses LE and OE signals to enter the test mode
void start_dimmer(void);       //enable main interrupt and start sending data to SPI

void stop_dimmer(void);        //disable main interrupt and stop sending data to SPI

void LED_driver_OutEnable(unsigned char which, unsigned char RGBchannel);

void LED_driver_OutDisable(unsigned char which, unsigned char RGBchannel);

void LED_driver_OutEnable_All_On(void);

void LED_driver_OutDisable_All_Off(void);

void SPI_CLK_LOW(void); void SPI_CLK_HIGH(void);

void use_new_table_immediately(unsigned char *table, unsigned char *tableKey, int table_size); //exchange table(SPI data) not preventing glitch,

void use_new_table_carefully(unsigned char *table, unsigned char *tableKey, int table_size); //exchange table(SPI data) preventing glitch, in right time
                                                     //take a new table and replace the pointers as soon as it is the right time
int new_table_not_changed_yet(void); //true till right time for table not reached
                               //remains true "1" till the new table pointers are not used and exchanged with the old ones.
int generateReducedLookUpTable(unsigned char *LEDmapIN, int LEDcount, int PWMdepth, unsigned char **tableIN, unsigned char **tableKeyIN, int *table_size);
                               //generate tables. Allocates memory and update table_size value. Returns "1" if successfull.
//void removeTableLookUpTable(unsigned char **table, unsigned char **tableKey);

void removeLookUpTableInUse(void);

void removeLookUpTableReleased(void);

void fillDriver(int LEDcount);

//u32 getSemiRnd(void);

/*
int generateFullLookUpTable(unsigned char *LEDmapIN, int LEDcount, int PWMdepth, unsigned char *table);
*/

void RCC_Configuration(void);
void NVIC_Configuration(void);
void SPI_GPIO_Init(void);
#endif

/*******************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/
