/**
  ******************************************************************************
  * @file TIM1_6Steps\stm8s_it.c
  * @brief This file contains all the interrupt routines.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 18-JUL-2008
  ******************************************************************************
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2008 STMicroelectronics</center></h2>
  * @image html logo.bmp
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "stm8s_it.h"

#include "led_dimmer.h"
#include "board_control.h"

extern int actual_PWMdepth;
extern unsigned int actual_streamSize;

extern unsigned char *actual_table_start;
extern unsigned char *actual_table_key_start;
extern int actual_table_size;

extern unsigned char *new_table_start;
extern unsigned char *new_table_key_start;
extern int new_table_size;

extern int new_table_not_changed_yet_flag;
static signed int depth = 0, index = 0, SPIStreamPosition = 0;

extern struct buttonsAndADC buttonsADC;

#define FAST_LE_LOW()     LE_PORT->ODR &= (u8)(~LE_PIN)  /* Latch Enable Low  */
#define FAST_LE_HIGH()    LE_PORT->ODR &= (u8)(LE_PIN)   /* Latch Enable Low  h */

@near @interrupt void NonHandledInterrupt(void){
  return;
}

@near @interrupt void TRAP_IRQHandler(void){
  return;
}

@near @interrupt void TLI_IRQHandler (void){
	buttonsADC.buttonCenter = 1;
  return;
}

@near @interrupt void AWU_IRQHandler (void){
  return;
}

@near @interrupt void CLK_IRQHandler (void){
  return;
}

@near @interrupt void EXTI_PORTA_IRQHandler (void){
  return;
}

@near @interrupt void EXTI_PORTB_IRQHandler (void){
  if(GPIO_ReadInputPin(ButtonLeftRight_Port, ButtonLeft_Pin))
    buttonsADC.buttonLeft = 1;
	if(GPIO_ReadInputPin(ButtonLeftRight_Port, ButtonRight_Pin))
    buttonsADC.buttonRight = 1;
  return;
}

@near @interrupt void EXTI_PORTC_IRQHandler (void){
  return;
}

@near @interrupt void EXTI_PORTD_IRQHandler (void){
  return;
}

@near @interrupt void EXTI_PORTE_IRQHandler (void){
  return;
}

@near @interrupt void CAN_RX_IRQHandler (void){
  return;
}

@near @interrupt void CAN_TX_IRQHandler (void){
  return;
}

@near @interrupt void SPI_IRQHandler (void)
{
	if(SPIStreamPosition < actual_streamSize) //!!@@:"
	{
    SPI->DR = (actual_table_start + index * actual_streamSize)[SPIStreamPosition];
    SPIStreamPosition++;
	}
	else
  {
	  SPI_ITConfig(SPI_IT_TXE, DISABLE);
    SPIStreamPosition = 0;
  	FAST_LE_HIGH();
    FAST_LE_LOW();
  
    GPIO_WriteHigh(LE_PORT, LE_PIN);  //FAST_LE_HIGH();
	  GPIO_WriteLow( LE_PORT, LE_PIN); //FAST_LE_LOW();	
	}	
	return;
}

@near @interrupt void TIM1_CAP_COM_IRQHandler (void){
  return;
}

@near @interrupt void TIM1_UPD_OVF_TRG_BRK_IRQHandler (void)
{
  #define SPI1_DR_Address   (SPI1_BASE + 0x000C)
  #define CCR_ENABLE_Set          ((u32)0x00000001)
  #define CCR_ENABLE_Reset        ((u32)0xFFFFFFFE)  
  #define DMA_IT_TC               ((u32)0x00000002)

  /* Clear TIM1 COM pending bit */
  TIM1_ClearITPendingBit(TIM1_IT_UPDATE);

  if(depth == 0){
    SPI_ITConfig(SPI_IT_TXE, ENABLE);
  }

  if(depth > actual_table_key_start[index+1]){
    if(index < (actual_table_size-1)){
      index ++;
      SPI_ITConfig(SPI_IT_TXE, ENABLE);
    }
  }
  
  if(depth > 0xFF){
    depth = 0;
    index = 0;
    if(new_table_not_changed_yet_flag){
       actual_table_start     = new_table_start;
       actual_table_key_start = new_table_key_start;
       actual_table_size      = new_table_size;
       index = 0;
       new_table_not_changed_yet_flag = 0;
    }
  }
  else
    depth ++;
  return;
}

@near @interrupt void TIM2_UPD_OVF_BRK_IRQHandler (void){
  return;
}

@near @interrupt void TIM2_CAP_COM_IRQHandler (void){
  return;
}

@near @interrupt void TIM3_UPD_OVF_BRK_IRQHandler (void){
  return;
}

@near @interrupt void TIM3_CAP_COM_IRQHandler (void){
  return;
}

@near @interrupt void UART2_TX_IRQHandler (void){
  return;
}

@near @interrupt void UART2_RX_IRQHandler (void){
  return;
}

@near @interrupt void I2C_IRQHandler (void){
  return;
}

@near @interrupt void UART1_TX_IRQHandler (void){
  return;
}

@near @interrupt void UART1_RX_IRQHandler (void){
  return;
}

@near @interrupt void ADC_IRQHandler (void){
  return;
}

@near @interrupt void TIM4_UPD_OVF_IRQHandler (void){
  return;
}

@near @interrupt void EEPROM_EEC_IRQHandler (void){
  return;
}


/******************* (C) COPYRIGHT 2008 STMicroelectronics *****END OF FILE****/
